import datetime
import random

from typing import Tuple

from randum.utils.checksums import calculate_luhn

from .. import Provider as SsnProvider


class Provider(SsnProvider):
    @staticmethod
    def _org_to_vat(org_id: str) -> str:
        org_id = org_id.replace("-", "")
        if len(org_id) == 10:
            org_id = "16" + org_id
        return f"SE{org_id}01"

    def ssn(
        self,
        min_age: int = 18,
        max_age: int = 90,
        long: bool = False,
        dash: bool = True,
    ) -> str:
        """
        Returns a 10 or 12 (long=True) digit Swedish SSN, "Personnummer".

        It consists of 10 digits in the form (CC)YYMMDD-SSSQ, where
        YYMMDD is the date of birth, SSS is a serial number
        and Q is a control character (Luhn checksum).

        Specifying dash=False will give a purely numeric string, suitable
        for writing direct to databases.

        http://en.wikipedia.org/wiki/Personal_identity_number_(Sweden)
        """

        age = datetime.timedelta(days=self.generator.random.randrange(min_age * 365, max_age * 365))
        birthday = datetime.datetime.now() - age
        yr_fmt = "%Y" if long else "%y"
        pnr_date = f"{birthday:{yr_fmt}%m%d}"
        chk_date = pnr_date[2:] if long else pnr_date
        suffix = f"{self.generator.random.randrange(0, 999):03}"
        luhn_checksum = str(calculate_luhn(int(chk_date + suffix)))
        hyphen = "-" if dash else ""
        pnr = f"{pnr_date}{hyphen}{suffix}{luhn_checksum}"

        return pnr

    ORG_ID_DIGIT_1 = (1, 2, 3, 5, 6, 7, 8, 9)

    def org_id(self, long: bool = False, dash: bool = True) -> str:
        """
        Returns a 10 or 12 digit Organisation ID for a Swedish
        company.
        (In Swedish) https://sv.wikipedia.org/wiki/Organisationsnummer
        """
        first_digits = list(self.ORG_ID_DIGIT_1)
        random.shuffle(first_digits)
        onr_one = str(first_digits.pop())
        onr_one += str(self.generator.random.randrange(0, 9)).zfill(1)
        onr_one += str(self.generator.random.randrange(20, 99))
        onr_one += str(self.generator.random.randrange(0, 99)).zfill(2)
        onr_two = str(self.generator.random.randrange(0, 999)).zfill(3)
        luhn_checksum = str(calculate_luhn(int(onr_one + onr_two)))
        prefix = "16" if long else ""
        hyphen = "-" if dash else ""

        org_id = f"{prefix}{onr_one}{hyphen}{onr_two}{luhn_checksum}"
        return org_id

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: A random Swedish VAT ID, based on a valid Org ID
        """
        oid = self.org_id(long=True, dash=False)
        vid = Provider._org_to_vat(oid)
        return vid

    def org_and_vat_id(self, long: bool = False, dash: bool = True) -> Tuple[str, str]:
        """Returns matching Org ID and VAT number"""
        oid = self.org_id(long=long, dash=dash)
        vid = Provider._org_to_vat(oid)
        return oid, vid



from typing import List

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``pl_PL`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Poland
    """

    license_formats = (
        "?? #####",
        "?? ####?",
        "?? ###??",
        "?? #?###",
        "?? #??##",
        "??? ?###",
        "??? ##??",
        "??? #?##",
        "??? ##?#",
        "??? #??#",
        "??? ??##",
        "??? #####",
        "??? ####?",
        "??? ###??",
    )

    def license_plate_regex_formats(self) -> List[str]:
        """Return a regex for matching license plates.

        .. warning::
           This is technically not a method that generates fake data, and it
           should not be part of the public API. User should refrain from using
           this method.
        """
        return [plate.replace("?", "[A-Z]").replace("#", "[0-9]") for plate in self.license_formats]



from .. import BaseProvider

localized = False


class Provider(BaseProvider):
    """Provider for food-related data."""

    # Fruits
    fruits = [
        "Apple", "Banana", "Orange", "Grape", "Strawberry", "Blueberry",
        "Raspberry", "Blackberry", "Mango", "Pineapple", "Watermelon",
        "Cantaloupe", "Honeydew", "Peach", "Pear", "Plum", "Cherry",
        "Apricot", "Kiwi", "Papaya", "Guava", "Passion Fruit", "Dragon Fruit",
        "Lychee", "Pomegranate", "Fig", "Date", "Coconut", "Avocado",
        "Lemon", "Lime", "Grapefruit", "Tangerine", "Clementine"
    ]

    # Vegetables
    vegetables = [
        "Carrot", "Broccoli", "Cauliflower", "Spinach", "Lettuce", "Kale",
        "Cabbage", "Brussels Sprouts", "Asparagus", "Celery", "Cucumber",
        "Zucchini", "Eggplant", "Bell Pepper", "Tomato", "Potato",
        "Sweet Potato", "Onion", "Garlic", "Ginger", "Radish", "Beet",
        "Turnip", "Parsnip", "Pumpkin", "Squash", "Corn", "Peas",
        "Green Beans", "Mushroom", "Artichoke", "Leek", "Chard", "Arugula"
    ]

    # Meats
    meats = [
        "Chicken", "Beef", "Pork", "Lamb", "Turkey", "Duck", "Veal",
        "Venison", "Rabbit", "Goat", "Bison", "Quail", "Pheasant",
        "Bacon", "Sausage", "Ham", "Salami", "Prosciutto", "Pepperoni"
    ]

    # Seafood
    seafood = [
        "Salmon", "Tuna", "Cod", "Halibut", "Trout", "Tilapia", "Mahi Mahi",
        "Swordfish", "Sea Bass", "Snapper", "Mackerel", "Sardine", "Anchovy",
        "Shrimp", "Crab", "Lobster", "Scallop", "Oyster", "Clam", "Mussel",
        "Squid", "Octopus", "Caviar"
    ]

    # Dairy products
    dairy = [
        "Milk", "Cheese", "Butter", "Yogurt", "Cream", "Sour Cream",
        "Cottage Cheese", "Cream Cheese", "Mozzarella", "Cheddar",
        "Parmesan", "Swiss Cheese", "Brie", "Gouda", "Feta", "Blue Cheese",
        "Ricotta", "Provolone", "Ice Cream", "Whipped Cream"
    ]

    # Grains and cereals
    grains = [
        "Rice", "Wheat", "Oats", "Barley", "Quinoa", "Corn", "Rye",
        "Millet", "Buckwheat", "Couscous", "Bulgur", "Farro", "Spelt",
        "Bread", "Pasta", "Noodles", "Cereal", "Granola", "Crackers"
    ]

    # Spices and herbs
    spices = [
        "Salt", "Pepper", "Cinnamon", "Nutmeg", "Ginger", "Garlic Powder",
        "Onion Powder", "Paprika", "Cumin", "Coriander", "Turmeric",
        "Cardamom", "Cloves", "Bay Leaf", "Oregano", "Basil", "Thyme",
        "Rosemary", "Sage", "Parsley", "Cilantro", "Dill", "Mint",
        "Chili Powder", "Cayenne", "Curry Powder", "Saffron", "Vanilla"
    ]

    # Desserts
    desserts = [
        "Cake", "Pie", "Cookie", "Brownie", "Cupcake", "Donut", "Muffin",
        "Ice Cream", "Cheesecake", "Tiramisu", "Pudding", "Mousse",
        "Tart", "Pastry", "Eclair", "Macaron", "Croissant", "Cannoli",
        "Baklava", "Flan", "Creme Brulee", "Panna Cotta", "Gelato",
        "Sorbet", "Cobbler", "Strudel", "Truffle", "Chocolate Bar"
    ]

    # Beverages
    beverages = [
        "Water", "Coffee", "Tea", "Juice", "Milk", "Soda", "Lemonade",
        "Iced Tea", "Hot Chocolate", "Smoothie", "Milkshake", "Beer",
        "Wine", "Champagne", "Cocktail", "Whiskey", "Vodka", "Rum",
        "Gin", "Tequila", "Sake", "Cider", "Energy Drink", "Sports Drink",
        "Coconut Water", "Kombucha", "Espresso", "Cappuccino", "Latte",
        "Mocha", "Americano", "Matcha", "Chai"
    ]

    # Cuisines
    cuisines = [
        "Italian", "Chinese", "Japanese", "Mexican", "Indian", "French",
        "Thai", "Greek", "Spanish", "Korean", "Vietnamese", "Turkish",
        "Lebanese", "Moroccan", "Ethiopian", "Brazilian", "Argentinian",
        "Peruvian", "Caribbean", "Mediterranean", "Middle Eastern",
        "American", "British", "German", "Russian", "Polish", "Irish",
        "Scandinavian", "African", "Fusion"
    ]

    # Cooking methods
    cooking_methods = [
        "Grilled", "Baked", "Fried", "Roasted", "Steamed", "Boiled",
        "Sautéed", "Braised", "Stewed", "Poached", "Broiled", "Smoked",
        "Barbecued", "Pan-Fried", "Deep-Fried", "Stir-Fried", "Blanched",
        "Seared", "Caramelized", "Glazed", "Marinated", "Pickled",
        "Fermented", "Raw", "Slow-Cooked"
    ]

    # Meal types
    meal_types = [
        "Breakfast", "Brunch", "Lunch", "Dinner", "Snack", "Appetizer",
        "Main Course", "Side Dish", "Dessert", "Buffet", "Tapas",
        "Tasting Menu", "Prix Fixe", "À la Carte"
    ]

    # Dish name templates
    dish_templates = [
        "{{cooking_method}} {{ingredient}}",
        "{{ingredient}} {{style}}",
        "{{cuisine}} {{ingredient}}",
        "{{ingredient}} with {{ingredient_2}}",
        "{{ingredient}} and {{ingredient_2}}",
        "{{cooking_method}} {{ingredient}} with {{ingredient_2}}",
        "{{cuisine}} Style {{ingredient}}",
        "{{ingredient}} {{cuisine}} Style",
    ]

    # Dish styles
    dish_styles = [
        "Soup", "Salad", "Sandwich", "Wrap", "Bowl", "Plate", "Platter",
        "Skewer", "Taco", "Burrito", "Pizza", "Burger", "Steak", "Curry",
        "Stir-Fry", "Casserole", "Risotto", "Paella", "Sushi", "Ramen"
    ]

    # Restaurant types
    restaurant_types = [
        "Fine Dining", "Casual Dining", "Fast Food", "Fast Casual", "Café",
        "Bistro", "Brasserie", "Pizzeria", "Steakhouse", "Seafood Restaurant",
        "Sushi Bar", "Ramen Shop", "Taco Stand", "Food Truck", "Diner",
        "Buffet", "Bakery", "Patisserie", "Ice Cream Parlor", "Juice Bar",
        "Coffee Shop", "Tea House", "Wine Bar", "Pub", "Gastropub"
    ]

    # Dietary preferences
    dietary_preferences = [
        "Vegetarian", "Vegan", "Gluten-Free", "Dairy-Free", "Nut-Free",
        "Kosher", "Halal", "Paleo", "Keto", "Low-Carb", "Low-Fat",
        "Sugar-Free", "Organic", "Raw", "Pescatarian"
    ]

    # Taste profiles
    taste_profiles = [
        "Sweet", "Salty", "Sour", "Bitter", "Umami", "Spicy", "Savory",
        "Tangy", "Smoky", "Creamy", "Crispy", "Crunchy", "Tender",
        "Juicy", "Rich", "Light", "Fresh", "Zesty", "Mild", "Bold"
    ]

    def food(self) -> str:
        """
        Generate a random food item from all categories.
        
        :example: 'Pizza'
        """
        all_foods = (
            self.fruits + self.vegetables + self.meats + 
            self.seafood + self.dairy + self.grains
        )
        return self.random_element(all_foods)

    def fruit(self) -> str:
        """
        Generate a random fruit name.
        
        :example: 'Apple'
        """
        return self.random_element(self.fruits)

    def vegetable(self) -> str:
        """
        Generate a random vegetable name.
        
        :example: 'Carrot'
        """
        return self.random_element(self.vegetables)

    def meat(self) -> str:
        """
        Generate a random meat type.
        
        :example: 'Chicken'
        """
        return self.random_element(self.meats)

    def seafood_item(self) -> str:
        """
        Generate a random seafood item.
        
        :example: 'Salmon'
        """
        return self.random_element(self.seafood)

    def dairy_product(self) -> str:
        """
        Generate a random dairy product.
        
        :example: 'Cheese'
        """
        return self.random_element(self.dairy)

    def grain(self) -> str:
        """
        Generate a random grain or cereal.
        
        :example: 'Rice'
        """
        return self.random_element(self.grains)

    def spice(self) -> str:
        """
        Generate a random spice or herb.
        
        :example: 'Cinnamon'
        """
        return self.random_element(self.spices)

    def dessert(self) -> str:
        """
        Generate a random dessert name.
        
        :example: 'Chocolate Cake'
        """
        return self.random_element(self.desserts)

    def beverage(self) -> str:
        """
        Generate a random beverage name.
        
        :example: 'Coffee'
        """
        return self.random_element(self.beverages)

    def cuisine(self) -> str:
        """
        Generate a random cuisine type.
        
        :example: 'Italian'
        """
        return self.random_element(self.cuisines)

    def cooking_method(self) -> str:
        """
        Generate a random cooking method.
        
        :example: 'Grilled'
        """
        return self.random_element(self.cooking_methods)

    def meal_type(self) -> str:
        """
        Generate a random meal type.
        
        :example: 'Breakfast'
        """
        return self.random_element(self.meal_types)

    def dish(self) -> str:
        """
        Generate a random dish name.
        
        :example: 'Grilled Salmon with Asparagus'
        """
        template = self.random_element(self.dish_templates)
        result = template
        
        # Get all ingredients for substitution
        all_ingredients = (
            self.fruits + self.vegetables + self.meats + 
            self.seafood + self.grains
        )
        
        # Replace placeholders
        if "{{cooking_method}}" in result:
            result = result.replace("{{cooking_method}}", self.random_element(self.cooking_methods))
        if "{{ingredient}}" in result:
            result = result.replace("{{ingredient}}", self.random_element(all_ingredients))
        if "{{ingredient_2}}" in result:
            result = result.replace("{{ingredient_2}}", self.random_element(all_ingredients))
        if "{{cuisine}}" in result:
            result = result.replace("{{cuisine}}", self.random_element(self.cuisines))
        if "{{style}}" in result:
            result = result.replace("{{style}}", self.random_element(self.dish_styles))
        
        return result

    def ingredient(self) -> str:
        """
        Generate a random ingredient.
        
        :example: 'Olive Oil'
        """
        all_ingredients = (
            self.fruits + self.vegetables + self.meats + 
            self.seafood + self.dairy + self.grains + self.spices
        )
        return self.random_element(all_ingredients)

    def restaurant_type(self) -> str:
        """
        Generate a random restaurant type.
        
        :example: 'Fine Dining'
        """
        return self.random_element(self.restaurant_types)

    def dietary_preference(self) -> str:
        """
        Generate a random dietary preference.
        
        :example: 'Vegetarian'
        """
        return self.random_element(self.dietary_preferences)

    def taste_profile(self) -> str:
        """
        Generate a random taste profile.
        
        :example: 'Sweet'
        """
        return self.random_element(self.taste_profiles)

    def recipe_name(self) -> str:
        """
        Generate a random recipe name.
        
        :example: 'Grandma's Secret Chocolate Cake'
        """
        templates = [
            "{{adjective}} {{dish}}",
            "{{name}}'s {{dish}}",
            "{{cuisine}} {{dish}}",
            "Homemade {{dish}}",
            "Classic {{dish}}",
            "Traditional {{dish}}",
            "Modern {{dish}}",
        ]
        
        adjectives = ["Secret", "Famous", "Special", "Delicious", "Perfect", 
                     "Ultimate", "Best", "Authentic", "Gourmet", "Rustic"]
        
        template = self.random_element(templates)
        result = template
        
        if "{{adjective}}" in result:
            result = result.replace("{{adjective}}", self.random_element(adjectives))
        if "{{name}}" in result:
            result = self.generator.parse(result)
        if "{{dish}}" in result:
            result = result.replace("{{dish}}", self.dessert() if self.random_int(0, 1) else self.random_element(self.dish_styles))
        if "{{cuisine}}" in result:
            result = result.replace("{{cuisine}}", self.random_element(self.cuisines))
        
        return result

    def food_price(self, min_price: float = 5.0, max_price: float = 50.0) -> str:
        """
        Generate a random food price.
        
        :param min_price: Minimum price (default: 5.0)
        :param max_price: Maximum price (default: 50.0)
        :example: '$12.99'
        """
        price = self.random_int(int(min_price * 100), int(max_price * 100)) / 100
        return f"${price:.2f}"

    def calories(self, min_cal: int = 100, max_cal: int = 1000) -> int:
        """
        Generate random calorie count.
        
        :param min_cal: Minimum calories (default: 100)
        :param max_cal: Maximum calories (default: 1000)
        :example: 450
        """
        return self.random_int(min_cal, max_cal)

    def serving_size(self) -> str:
        """
        Generate a random serving size.
        
        :example: '2 cups'
        """
        amounts = ["1/4", "1/2", "3/4", "1", "2", "3", "4", "6", "8"]
        units = ["cup", "cups", "tablespoon", "tablespoons", "teaspoon", 
                "teaspoons", "oz", "lb", "g", "kg", "ml", "L", "piece", "pieces"]
        
        amount = self.random_element(amounts)
        unit = self.random_element(units)
        
        return f"{amount} {unit}"



from .. import BaseProvider

localized = False


class Provider(BaseProvider):
    """Provider for sport-related data."""

    # Sports categories
    sports = [
        # Ball sports
        "Football", "Soccer", "Basketball", "Baseball", "Tennis", "Volleyball",
        "Cricket", "Rugby", "Golf", "Table Tennis", "Badminton", "Handball",
        "Squash", "Racquetball", "Lacrosse", "Field Hockey", "Ice Hockey",
        "Water Polo", "Polo", "Softball", "Beach Volleyball",
        
        # Combat sports
        "Boxing", "Wrestling", "Judo", "Karate", "Taekwondo", "Kickboxing",
        "Mixed Martial Arts", "Fencing", "Sumo Wrestling", "Muay Thai",
        
        # Water sports
        "Swimming", "Diving", "Surfing", "Water Skiing", "Wakeboarding",
        "Rowing", "Kayaking", "Canoeing", "Sailing", "Windsurfing",
        
        # Winter sports
        "Skiing", "Snowboarding", "Ice Skating", "Figure Skating", "Speed Skating",
        "Curling", "Bobsled", "Luge", "Biathlon", "Cross-Country Skiing",
        
        # Athletics
        "Track and Field", "Marathon", "Sprinting", "Long Jump", "High Jump",
        "Pole Vault", "Shot Put", "Discus Throw", "Javelin Throw", "Hurdles",
        
        # Other sports
        "Cycling", "Mountain Biking", "Gymnastics", "Weightlifting", "Archery",
        "Shooting", "Equestrian", "Rock Climbing", "Skateboarding", "BMX",
        "Triathlon", "Decathlon", "Pentathlon"
    ]

    # Team sports
    team_sports = [
        "Football", "Soccer", "Basketball", "Baseball", "Volleyball", "Cricket",
        "Rugby", "Handball", "Field Hockey", "Ice Hockey", "Water Polo",
        "Lacrosse", "Softball", "Beach Volleyball"
    ]

    # Individual sports
    individual_sports = [
        "Tennis", "Golf", "Boxing", "Swimming", "Gymnastics", "Track and Field",
        "Cycling", "Skiing", "Snowboarding", "Surfing", "Skateboarding",
        "Archery", "Shooting", "Fencing", "Wrestling", "Judo", "Karate"
    ]

    # Olympic sports
    olympic_sports = [
        "Athletics", "Swimming", "Gymnastics", "Basketball", "Football",
        "Volleyball", "Tennis", "Boxing", "Wrestling", "Judo", "Taekwondo",
        "Fencing", "Archery", "Shooting", "Cycling", "Rowing", "Sailing",
        "Diving", "Water Polo", "Handball", "Hockey", "Rugby", "Golf",
        "Surfing", "Skateboarding", "Sport Climbing", "Karate", "Badminton",
        "Table Tennis", "Weightlifting", "Triathlon", "Modern Pentathlon"
    ]

    # Sports positions (generic)
    positions = [
        # General positions
        "Forward", "Midfielder", "Defender", "Goalkeeper", "Center", "Guard",
        "Striker", "Winger", "Fullback", "Halfback", "Quarterback", "Running Back",
        "Wide Receiver", "Tight End", "Linebacker", "Cornerback", "Safety",
        "Pitcher", "Catcher", "Infielder", "Outfielder", "Point Guard",
        "Shooting Guard", "Small Forward", "Power Forward", "Center Back",
        "Left Back", "Right Back", "Defensive Midfielder", "Attacking Midfielder"
    ]

    # Sports equipment
    equipment = [
        "Ball", "Bat", "Racket", "Club", "Stick", "Puck", "Net", "Goal",
        "Helmet", "Pads", "Gloves", "Cleats", "Shoes", "Jersey", "Shorts",
        "Shin Guards", "Mouthguard", "Goggles", "Swimsuit", "Skis", "Snowboard",
        "Skateboard", "Bicycle", "Surfboard", "Kayak", "Canoe", "Rowing Machine",
        "Weights", "Barbell", "Dumbbell", "Kettlebell", "Jump Rope", "Mat",
        "Punching Bag", "Boxing Gloves", "Fencing Sword", "Bow and Arrow",
        "Target", "Stopwatch", "Whistle", "Scoreboard"
    ]

    # Sports venues
    venues = [
        "Stadium", "Arena", "Court", "Field", "Pitch", "Track", "Pool",
        "Rink", "Gym", "Gymnasium", "Sports Complex", "Coliseum", "Dome",
        "Ballpark", "Golf Course", "Tennis Court", "Basketball Court",
        "Soccer Field", "Football Stadium", "Baseball Diamond", "Ice Rink",
        "Swimming Pool", "Velodrome", "Ski Resort", "Skate Park"
    ]

    # Famous sports venues
    famous_venues = [
        "Wembley Stadium", "Madison Square Garden", "Camp Nou", "Old Trafford",
        "Yankee Stadium", "Fenway Park", "Wimbledon", "Augusta National",
        "Melbourne Cricket Ground", "Maracanã Stadium", "San Siro",
        "Allianz Arena", "Santiago Bernabéu", "Anfield", "Emirates Stadium",
        "Staples Center", "TD Garden", "United Center", "Oracle Arena"
    ]

    # Sports leagues
    leagues = [
        "NFL", "NBA", "MLB", "NHL", "MLS", "Premier League", "La Liga",
        "Serie A", "Bundesliga", "Ligue 1", "UEFA Champions League",
        "FIFA World Cup", "Olympics", "NCAA", "ATP Tour", "WTA Tour",
        "PGA Tour", "Formula 1", "NASCAR", "IndyCar", "UFC", "WWE"
    ]

    # Sports awards
    awards = [
        "MVP", "Rookie of the Year", "Coach of the Year", "Defensive Player of the Year",
        "Golden Boot", "Golden Ball", "Golden Glove", "Ballon d'Or",
        "Heisman Trophy", "Cy Young Award", "Gold Medal", "Silver Medal",
        "Bronze Medal", "Championship Trophy", "World Cup Trophy",
        "Stanley Cup", "Super Bowl Ring", "NBA Championship Ring",
        "Olympic Gold Medal", "Hall of Fame Induction"
    ]

    # Sports terms
    terms = [
        "Goal", "Score", "Point", "Touchdown", "Home Run", "Slam Dunk",
        "Hat Trick", "Grand Slam", "Ace", "Birdie", "Eagle", "Bogey",
        "Knockout", "Submission", "Pin", "Checkmate", "Serve", "Volley",
        "Dribble", "Pass", "Tackle", "Block", "Steal", "Rebound",
        "Assist", "Penalty", "Foul", "Offside", "Timeout", "Overtime",
        "Sudden Death", "Playoff", "Championship", "Tournament", "Match",
        "Game", "Set", "Round", "Quarter", "Half", "Inning", "Period"
    ]

    # Team name templates
    team_name_templates = [
        "{{city}} {{mascot}}",
        "{{word}} {{mascot}}",
        "The {{mascot}}",
        "{{city}} {{word}}",
    ]

    # Team mascots
    mascots = [
        "Lions", "Tigers", "Bears", "Eagles", "Hawks", "Falcons", "Ravens",
        "Cardinals", "Bulls", "Rams", "Broncos", "Colts", "Panthers",
        "Jaguars", "Dolphins", "Sharks", "Wolves", "Coyotes", "Wildcats",
        "Bulldogs", "Huskies", "Terriers", "Warriors", "Knights", "Spartans",
        "Trojans", "Vikings", "Pirates", "Raiders", "Rangers", "Giants",
        "Titans", "Thunder", "Lightning", "Storm", "Heat", "Suns", "Stars",
        "Flames", "Avalanche", "Hurricanes", "Cyclones", "Tornadoes"
    ]

    # Sport words for team names
    sport_words = [
        "United", "City", "Athletic", "Sporting", "Real", "Royal", "Olympic",
        "National", "International", "Metropolitan", "Capital", "Central"
    ]

    def sport(self) -> str:
        """
        Generate a random sport name.
        
        :example: 'Basketball'
        """
        return self.random_element(self.sports)

    def team_sport(self) -> str:
        """
        Generate a random team sport name.
        
        :example: 'Football'
        """
        return self.random_element(self.team_sports)

    def individual_sport(self) -> str:
        """
        Generate a random individual sport name.
        
        :example: 'Tennis'
        """
        return self.random_element(self.individual_sports)

    def olympic_sport(self) -> str:
        """
        Generate a random Olympic sport name.
        
        :example: 'Swimming'
        """
        return self.random_element(self.olympic_sports)

    def sport_position(self) -> str:
        """
        Generate a random sport position.
        
        :example: 'Quarterback'
        """
        return self.random_element(self.positions)

    def sport_equipment(self) -> str:
        """
        Generate a random sport equipment item.
        
        :example: 'Ball'
        """
        return self.random_element(self.equipment)

    def sport_venue(self) -> str:
        """
        Generate a random sport venue type.
        
        :example: 'Stadium'
        """
        return self.random_element(self.venues)

    def famous_sport_venue(self) -> str:
        """
        Generate a random famous sport venue name.
        
        :example: 'Wembley Stadium'
        """
        return self.random_element(self.famous_venues)

    def sport_league(self) -> str:
        """
        Generate a random sport league or competition name.
        
        :example: 'NBA'
        """
        return self.random_element(self.leagues)

    def sport_award(self) -> str:
        """
        Generate a random sport award name.
        
        :example: 'MVP'
        """
        return self.random_element(self.awards)

    def sport_term(self) -> str:
        """
        Generate a random sport term.
        
        :example: 'Touchdown'
        """
        return self.random_element(self.terms)

    def team_name(self) -> str:
        """
        Generate a random team name.
        
        :example: 'Chicago Bulls'
        """
        template = self.random_element(self.team_name_templates)
        result = template
        
        # First replace custom placeholders manually (before generator.parse)
        if "{{mascot}}" in result:
            result = result.replace("{{mascot}}", self.random_element(self.mascots))
        if "{{word}}" in result:
            result = result.replace("{{word}}", self.random_element(self.sport_words))
        if "{{word_2}}" in result:
            result = result.replace("{{word_2}}", self.random_element(self.sport_words))
        
        # Then replace city placeholder using generator if present
        if "{{city}}" in result:
            result = self.generator.parse(result)
        
        return result

    def athlete_name(self) -> str:
        """
        Generate a random athlete name.
        
        :example: 'Michael Jordan'
        """
        return self.generator.parse("{{first_name}} {{last_name}}")

    def score(self, min_score: int = 0, max_score: int = 100) -> int:
        """
        Generate a random sport score.
        
        :param min_score: Minimum score (default: 0)
        :param max_score: Maximum score (default: 100)
        :example: 42
        """
        return self.random_int(min_score, max_score)

    def jersey_number(self, min_number: int = 0, max_number: int = 99) -> int:
        """
        Generate a random jersey number.
        
        :param min_number: Minimum number (default: 0)
        :param max_number: Maximum number (default: 99)
        :example: 23
        """
        return self.random_int(min_number, max_number)

    def season_year(self, min_year: int = 1950, max_year: int = 2024) -> str:
        """
        Generate a random season year in format 'YYYY-YY'.
        
        :param min_year: Minimum year (default: 1950)
        :param max_year: Maximum year (default: 2024)
        :example: '2023-24'
        """
        year = self.random_int(min_year, max_year)
        next_year = str(year + 1)[-2:]
        return f"{year}-{next_year}"

    def game_duration(self, min_minutes: int = 60, max_minutes: int = 120) -> str:
        """
        Generate a random game duration in MM:SS format.
        
        :param min_minutes: Minimum duration in minutes (default: 60)
        :param max_minutes: Maximum duration in minutes (default: 120)
        :example: '90:00'
        """
        minutes = self.random_int(min_minutes, max_minutes)
        seconds = self.random_int(0, 59)
        return f"{minutes}:{seconds:02d}"

    def record(self, wins_max: int = 82, losses_max: int = 82) -> str:
        """
        Generate a random win-loss record.
        
        :param wins_max: Maximum wins (default: 82)
        :param losses_max: Maximum losses (default: 82)
        :example: '45-37'
        """
        wins = self.random_int(0, wins_max)
        losses = self.random_int(0, losses_max)
        return f"{wins}-{losses}"

    def ranking(self, max_rank: int = 100) -> int:
        """
        Generate a random ranking position.
        
        :param max_rank: Maximum rank (default: 100)
        :example: 5
        """
        return self.random_int(1, max_rank)



from randum.utils.datasets import add_ordereddicts

from .. import BaseProvider, ElementsType

localized = True


class Provider(BaseProvider):
    formats: ElementsType[str] = ["{{first_name}} {{last_name}}"]

    first_names: ElementsType[str] = ["John", "Jane"]

    last_names: ElementsType[str] = ["Doe"]

    # https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes
    language_names: ElementsType[str] = [
        "Afar",
        "Abkhazian",
        "Avestan",
        "Afrikaans",
        "Akan",
        "Amharic",
        "Aragonese",
        "Arabic",
        "Assamese",
        "Avaric",
        "Aymara",
        "Azerbaijani",
        "Bashkir",
        "Belarusian",
        "Bulgarian",
        "Bihari languages",
        "Bislama",
        "Bambara",
        "Bengali",
        "Tibetan",
        "Breton",
        "Bosnian",
        "Catalan",
        "Chechen",
        "Chamorro",
        "Corsican",
        "Cree",
        "Czech",
        "Church Slavic",
        "Chuvash",
        "Welsh",
        "Danish",
        "German",
        "Divehi",
        "Dzongkha",
        "Ewe",
        "Greek",
        "English",
        "Esperanto",
        "Spanish",
        "Estonian",
        "Basque",
        "Persian",
        "Fulah",
        "Finnish",
        "Fijian",
        "Faroese",
        "French",
        "Western Frisian",
        "Irish",
        "Gaelic",
        "Galician",
        "Guarani",
        "Gujarati",
        "Manx",
        "Hausa",
        "Hebrew",
        "Hindi",
        "Hiri Motu",
        "Croatian",
        "Haitian",
        "Hungarian",
        "Armenian",
        "Herero",
        "Interlingua",
        "Indonesian",
        "Interlingue",
        "Igbo",
        "Sichuan Yi",
        "Inupiaq",
        "Ido",
        "Icelandic",
        "Italian",
        "Inuktitut",
        "Japanese",
        "Javanese",
        "Georgian",
        "Kongo",
        "Kikuyu",
        "Kuanyama",
        "Kazakh",
        "Kalaallisut",
        "Central Khmer",
        "Kannada",
        "Korean",
        "Kanuri",
        "Kashmiri",
        "Kurdish",
        "Komi",
        "Cornish",
        "Kirghiz",
        "Latin",
        "Luxembourgish",
        "Ganda",
        "Limburgan",
        "Lingala",
        "Lao",
        "Lithuanian",
        "Luba-Katanga",
        "Latvian",
        "Malagasy",
        "Marshallese",
        "Maori",
        "Macedonian",
        "Malayalam",
        "Mongolian",
        "Marathi",
        "Malay",
        "Maltese",
        "Burmese",
        "Nauru",
        "North Ndebele",
        "Nepali",
        "Ndonga",
        "Dutch",
        "Norwegian Nynorsk",
        "Norwegian",
        "South Ndebele",
        "Navajo",
        "Chichewa",
        "Occitan",
        "Ojibwa",
        "Oromo",
        "Oriya",
        "Ossetian",
        "Panjabi",
        "Pali",
        "Polish",
        "Pushto",
        "Portuguese",
        "Quechua",
        "Romansh",
        "Rundi",
        "Romanian",
        "Russian",
        "Kinyarwanda",
        "Sanskrit",
        "Sardinian",
        "Sindhi",
        "Northern Sami",
        "Sango",
        "Sinhala",
        "Slovak",
        "Slovenian",
        "Samoan",
        "Shona",
        "Somali",
        "Albanian",
        "Serbian",
        "Swati",
        "Sotho, Southern",
        "Sundanese",
        "Swedish",
        "Swahili",
        "Tamil",
        "Telugu",
        "Tajik",
        "Thai",
        "Tigrinya",
        "Turkmen",
        "Tagalog",
        "Tswana",
        "Tonga",
        "Turkish",
        "Tsonga",
        "Tatar",
        "Twi",
        "Tahitian",
        "Uighur",
        "Ukrainian",
        "Urdu",
        "Uzbek",
        "Venda",
        "Vietnamese",
        "Walloon",
        "Wolof",
        "Xhosa",
        "Yiddish",
        "Yoruba",
        "Zhuang",
        "Chinese",
        "Zulu",
    ]

    def name(self) -> str:
        """
        :example: 'John Doe'
        """
        pattern: str = self.random_element(self.formats)
        return self.generator.parse(pattern)

    def first_name(self) -> str:
        return self.random_element(self.first_names)

    def last_name(self) -> str:
        return self.random_element(self.last_names)

    def name_male(self) -> str:
        if hasattr(self, "formats_male"):
            formats = self.formats_male  # type: ignore[attr-defined]
        else:
            formats = self.formats
        pattern: str = self.random_element(formats)
        return self.generator.parse(pattern)

    def name_nonbinary(self) -> str:
        if hasattr(self, "formats_nonbinary"):
            formats = self.formats_nonbinary  # type: ignore[attr-defined]
        else:
            formats = self.formats
        pattern: str = self.random_element(formats)
        return self.generator.parse(pattern)

    def name_female(self) -> str:
        if hasattr(self, "formats_female"):
            formats = self.formats_female  # type: ignore[attr-defined]
        else:
            formats = self.formats
        pattern: str = self.random_element(formats)
        return self.generator.parse(pattern)

    def first_name_male(self) -> str:
        if hasattr(self, "first_names_male"):
            return self.random_element(self.first_names_male)  # type: ignore[attr-defined]
        return self.first_name()

    def first_name_nonbinary(self) -> str:
        if hasattr(self, "first_names_nonbinary"):
            return self.random_element(self.first_names_nonbinary)  # type: ignore[attr-defined]
        return self.first_name()

    def first_name_female(self) -> str:
        if hasattr(self, "first_names_female"):
            return self.random_element(self.first_names_female)  # type: ignore[attr-defined]
        return self.first_name()

    def last_name_male(self) -> str:
        if hasattr(self, "last_names_male"):
            return self.random_element(self.last_names_male)  # type: ignore[attr-defined]
        return self.last_name()

    def last_name_nonbinary(self) -> str:
        if hasattr(self, "last_names_nonbinary"):
            return self.random_element(self.last_names_nonbinary)  # type: ignore[attr-defined]
        return self.last_name()

    def last_name_female(self) -> str:
        if hasattr(self, "last_names_female"):
            return self.random_element(self.last_names_female)  # type: ignore[attr-defined]
        return self.last_name()

    def prefix(self) -> str:
        if hasattr(self, "prefixes"):
            return self.random_element(self.prefixes)  # type: ignore[attr-defined]
        if hasattr(self, "prefixes_male") and hasattr(self, "prefixes_female") and hasattr(self, "prefixes_nonbinary"):
            prefixes = add_ordereddicts(
                self.prefixes_male,  # type: ignore[attr-defined]
                self.prefixes_female,  # type: ignore[attr-defined]
                self.prefixes_nonbinary,  # type: ignore[attr-defined]
            )
            return self.random_element(prefixes)
        if hasattr(self, "prefixes_male") and hasattr(self, "prefixes_female"):
            prefixes = self.random_element((self.prefixes_male, self.prefixes_female))  # type: ignore[attr-defined]
            return self.random_element(prefixes)
        return ""

    def prefix_male(self) -> str:
        if hasattr(self, "prefixes_male"):
            return self.random_element(self.prefixes_male)  # type: ignore[attr-defined]
        return self.prefix()

    def prefix_nonbinary(self) -> str:
        if hasattr(self, "prefixes_nonbinary"):
            return self.random_element(self.prefixes_nonbinary)  # type: ignore[attr-defined]
        return self.prefix()

    def prefix_female(self) -> str:
        if hasattr(self, "prefixes_female"):
            return self.random_element(self.prefixes_female)  # type: ignore[attr-defined]
        return self.prefix()

    def suffix(self) -> str:
        if hasattr(self, "suffixes"):
            return self.random_element(self.suffixes)  # type: ignore[attr-defined]
        if hasattr(self, "suffixes_male") and hasattr(self, "suffixes_female") and hasattr(self, "suffixes_nonbinary"):
            suffixes = add_ordereddicts(
                self.suffixes_male,  # type: ignore[attr-defined]
                self.suffixes_female,  # type: ignore[attr-defined]
                self.suffixes_nonbinary,  # type: ignore[attr-defined]
            )
            return self.random_element(suffixes)
        if hasattr(self, "suffixes_male") and hasattr(self, "suffixes_female"):
            suffixes = self.random_element((self.suffixes_male, self.suffixes_female))  # type: ignore[attr-defined]
            return self.random_element(suffixes)
        return ""

    def suffix_male(self) -> str:
        if hasattr(self, "suffixes_male"):
            return self.random_element(self.suffixes_male)  # type: ignore[attr-defined]
        return self.suffix()

    def suffix_nonbinary(self) -> str:
        if hasattr(self, "suffixes_nonbinary"):
            return self.random_element(self.suffixes_nonbinary)  # type: ignore[attr-defined]
        return self.suffix()

    def suffix_female(self) -> str:
        if hasattr(self, "suffixes_female"):
            return self.random_element(self.suffixes_female)  # type: ignore[attr-defined]
        return self.suffix()

    def language_name(self) -> str:
        """Generate a random i18n language name (e.g. English)."""
        return self.random_element(self.language_names)



# Configuration file for the Sphinx documentation builder.

import os
import sys
sys.path.insert(0, os.path.abspath('..'))

# -- Project information -----------------------------------------------------
project = 'Randum'
copyright = '2026, Raja CSP Raman'
author = 'Raja CSP Raman'
release = '1.0.7'

# -- General configuration ---------------------------------------------------
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.napoleon',
    'sphinx.ext.viewcode',
    'sphinx.ext.intersphinx',
    'sphinx_rtd_theme',
]

templates_path = ['_templates']
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']

# -- Options for HTML output -------------------------------------------------
html_theme = 'sphinx_rtd_theme'
html_static_path = ['_static']

# -- Extension configuration -------------------------------------------------
autodoc_member_order = 'bysource'
napoleon_google_docstring = True
napoleon_numpy_docstring = True

intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
}



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    Source: https://star.dk/it/saadan-arbejder-vi-med-it-i-styrelsen/oversigt-over-stillingsbetegnelser-og-kvalifikationer/.  # NOQA
    """

    jobs = [
        "Lastvognsmekanikerlærling",
        "Knallertmekaniker",
        "Møbelarkitekt",
        "Forsyningsoperatørelev",
        "Hospitalsfysiker",
        "Økonomicontroller",
        "Revisor",
        "Skatterevisor",
        "Kontrollør",
        "Musikpædagog",
        "Pantefoged",
        "Serveringsmedarbejder",
        "Maskinmesteraspirant",
        "Sygehusdirektør",
        "Laborant",
        "Overlæge",
        "Designassistent",
        "Teknisk chef",
        "Socialformidler",
        "Overassistent",
        "Pædagogisk assistent",
        "Pedel",
        "Kustode",
        "Pædagogmedhjælper",
        "Projektmedarbejder",
        "Pedelmedhjælper",
        "Museumsbetjent",
        "Molekylærbiolog",
        "Lærervikar",
        "Sognehjælper",
        "Lysdesigner",
        "Instruktørassistent",
        "Teatertekniker",
        "Researcher",
        "Redaktør",
        "Teknisk designer",
        "Ressourceleder",
        "Indkøbschef",
        "E-commerce manager",
        "Kontraktchef",
        "Produktchef",
        "Museumsinspektør",
        "Kurator",
        "Konservator",
        "Modelkonstruktør",
        "Kommunikationschef",
        "Forskningschef",
        "Skovrider",
        "Fiskeriteknolog",
        "Produktionschef",
        "Driftsleder",
        "Direktør",
        "Officer",
        "Sergent",
        "IT-ingeniør",
        "IT-arkitekt",
        "IT-revisor",
        "Programmør og systemudvikler",
        "UX designer",
        "Webredaktør",
        "Webudvikler",
        "Datakonsulent",
        "Idrætsinstruktør og -konsulent",
        "Efterretningsofficer",
        "Miljøkonsulent",
        "Campingpladsbestyrer",
        "Miljøkoordinator",
        "Grafisk tekniker",
        "Elektrotekniker",
        "Vindmølleoperatør",
        "Urmager",
        "Byplanlægger",
        "Trafikplanlægger",
        "GIS-medarbejder",
        "Illustrator",
        "Mediegrafiker",
        "Artdirector",
        "Multimediedesigner",
        "Praktiserende læge",
        "Speciallæge",
        "Struktør",
        "Pakkerimedarbejder",
        "Cykelbud",
        "Fabriksbager",
        "Møller",
        "Guld- og sølvsmed",
        "Ciselør",
        "Produktionsleder inden for film og teater",
        "Centerleder",
        "Lufthavnschef",
        "Kameramand",
        "Tonemester",
        "Studietekniker",
        "Eventtekniker",
        "Produktionstekniker",
        "Fødevareteknolog",
        "Brygmester",
        "Specialist i biomedicin",
        "Botaniker",
        "Biokemiker",
        "Havbiolog",
        "Fysiolog",
        "Planteforædler",
        "Skoleleder",
        "Døvekonsulent",
        "Import- og eksportmedarbejder",
        "Friskolelærer",
        "Au pair",
        "Børnepasser",
        "Landbrugsmaskinemekaniker",
        "Trafikinformationsmedarbejder",
        "Togfører",
        "Guide",
        "Kok",
        "Vært i restaurant",
        "Tjener",
        "Bartender",
        "Korrekturlæser",
        "Postfunktionær",
        "Biblioteksassistent",
        "Telefonist",
        "Kundeservicemedarbejder",
        "Natportier",
        "Interviewer",
        "Vekselbureaumedarbejder",
        "Skattefunktionær",
        "Forsikringsfunktionær",
        "Revisorassistent",
        "Lønbogholder",
        "Lagerforvalter",
        "Overstyrmand",
        "Flyklarerer",
        "Marketingmedarbejder",
        "Kreativ chef",
        "Miljøanalytiker",
        "Naturvejleder",
        "Procesingeniør",
        "Logistiker",
        "Bankdirektør",
        "Civilingeniør",
        "Miljøingeniør",
        "Maskiningeniør",
        "Værkstedsleder",
        "Programdirektør",
        "Lystekniker",
        "IT-supporter",
        "IT-tekniker",
        "IT-kvalitetsmedarbejder",
        "Korleder",
        "Marketingchef",
        "Destinationschef",
        "Ordblindelærer",
        "Kursusleder",
        "Produktspecialist",
        "Områdechef",
        "Rengøringsinspektør",
        "Smedelærling",
        "Stenhuggerlærling",
        "Shippingmedarbejder",
        "Lager- og logistikelev",
        "Stukkatørlærling",
        "Automekanikerlærling",
        "Beklædningshåndværkerelev",
        "Butikselev",
        "Datateknikerelev",
        "Industrislagterlærling",
        "Shippingassistent",
        "Konditorlærling",
        "Gulvlæggerlærling",
        "Køleteknikerlærling",
        "Bygningstruktørlærling",
        "Rustfast industrimontør",
        "Værktøjsmagerlærling",
        "Industriteknikerlærling",
        "Vagtcentralassistent",
        "Juridisk chef",
        "Kunstlærer",
        "Lærer på skuespillerskole",
        "Asfaltør",
        "Jordemoder",
        "Erhvervsskolelærer",
        "Personalekonsulent",
        "Job- og virksomhedskonsulent",
        "Tekstforfatter",
        "Virksomhedsudvikler",
        "Byggeleder",
        "Departementschef",
        "Politidirektør",
        "Diplomat",
        "Generalsekretær",
        "Leder af offentlig forvaltning",
        "Konstabel",
        "Speditør",
        "Flyttearbejder",
        "Lager- og logistikmedarbejder",
        "Havnearbejder",
        "Anlægsarbejder",
        "Slagteriarbejder",
        "Fiskeindustriarbejder",
        "Industrislagter",
        "Slagtermester",
        "Bager",
        "Konditor",
        "Mejeriarbejder",
        "Mejerist",
        "Familievejleder",
        "Socialfaglig leder",
        "HR-konsulent",
        "SSP-medarbejder",
        "Havnefoged",
        "Lufthavnsoperatør",
        "Assistent til salgssupport",
        "Frisør",
        "Model",
        "Demonstratør",
        "Call centermedarbejder",
        "Viceskoleleder",
        "Ortopædiskomager",
        "Fiskeribetjent",
        "Indkøber",
        "Massageterapeut",
        "Levnedsmiddelinspektør",
        "Ambulancefører",
        "Paramediciner",
        "Kunstformidler",
        "Arkivar",
        "Registrar",
        "Bibliotekar",
        "Økonom",
        "Antropolog",
        "Arkæolog",
        "Motorcykelmekanikerlærling",
        "Skibsmekanikerlærling",
        "Landbrugsmaskine-mekanikerlærling",
        "VVS-lærling",
        "Privatpraktiserende tandplejer",
        "Glarmesterlærling",
        "Ejendomsserviceteknikerelev",
        "Audiologiassistentelev",
        "Dyrepasserelev",
        "Tømrerlærling",
        "Autolakererlærling",
        "Bygningsmalerlærling",
        "Automatikteknikerelev",
        "Skorstensfejerlærling",
        "Bagerlærling",
        "Vagtcentralmedarbejder",
        "Murerlærling",
        "Elektrikerlærling",
        "Rørlægger",
        "Flymekanikerlærling",
        "Cykelmekanikerlærling",
        "Skibsmontørlærling",
        "Bygningssnedkerlærling",
        "Studentermedhjælp",
        "Redder",
        "Chaufførelev",
        "Slagterlærling",
        "Tagdækkerlærling",
        "Organist",
        "Sagsbehandler",
        "Databaseadministrator",
        "Bankrådgiver",
        "Realkreditmedarbejder",
        "Bogholder",
        "Bogholderi- og regnskabsassistent",
        "Assurandør",
        "Valuar",
        "Taksator",
        "Hardware-udvikler",
        "Medicoingeniør",
        "Sensortekniker",
        "Boghandler",
        "Ekspedient",
        "Fiskehandler",
        "Farvehandler",
        "Blomsterbinder",
        "Delikatesseassistent",
        "Farmakonom",
        "Serviceøkonom",
        "SOME-medarbejder",
        "Pressesekretær",
        "Fundraiser",
        "Kampagnemedarbejder",
        "Kommunikationskonsulent",
        "IT-konsulent",
        "IT-direktør",
        "IT-chef",
        "IT-dokumentationschef",
        "Chief data officer",
        "IT-projektleder",
        "Børne- og ungekoordinator",
        "Leder af børne- og ungdomsklub",
        "Børsmægler",
        "Lagerekspedient",
        "Sommelier",
        "Levnedsmiddelingeniør",
        "Vagt",
        "Dørmand",
        "Barista",
        "Tekster",
        "Flyinstruktør",
        "Helikopterfører",
        "Flymaskinist",
        "Klimaforsker",
        "Handelsskolelærer",
        "Møbelpolstrer",
        "Børneværnskonsulent",
        "Klargører",
        "Klubmedarbejder",
        "Kontorchef",
        "Koordinator",
        "Efterskoleforstander",
        "Vicerektor",
        "Politisk medarbejder",
        "Politisk konsulent",
        "Kommunal planlægger",
        "Fuldmægtig",
        "Rådgivende konsulent",
        "Business intelligence manager",
        "Økonomiassistent",
        "Finansanalytiker",
        "Gymnasielærer",
        "Folkeskolelærer",
        "Pædagog",
        "Studiesekretær",
        "Speciallærer",
        "Fotografmedhjælper",
        "Erhvervsdykker",
        "Danselærer",
        "Geograf",
        "Kriminolog",
        "Sociolog",
        "Historiker",
        "Filosof",
        "Socialrådgiver",
        "Politolog",
        "Psykolog",
        "Socialarbejder",
        "Socialpædagog",
        "Præst",
        "Geotekniker",
        "Svejseinspektør",
        "Designer",
        "Merchandiser",
        "Visual merchandiser",
        "Scenograf",
        "Tandklinikassistent",
        "Tandplejer",
        "Keramiker",
        "Gravør",
        "Kunstner",
        "Tegner",
        "Garver",
        "Landinspektør",
        "Byggemontagetekniker",
        "Brolægger",
        "Forskningsbibliotekar",
        "Anlægsgartnerarbejder",
        "Cafemedarbejder",
        "Kontorleder",
        "Farmakonomelev",
        "Rejsebureauelev",
        "Tandplejerelev",
        "Tandteknikerelev",
        "Frisørelev",
        "Receptionistelev",
        "Vejrvært",
        "Arrangementchef",
        "Udviklingschef",
        "Indretningsarkitekt",
        "Autoteknolog",
        "Butiksassistent",
        "Skolepædagog",
        "Social- og sundhedsassistent",
        "Social- og sundhedshjælper",
        "Kasseassistent",
        "Levnedsmiddeltekniker",
        "Maskinsnedker",
        "Møbelsnedker",
        "Automationsingeniør",
        "Produktionsmedarbejder",
        "Byggetekniker",
        "Reklamechef",
        "Sproglærer",
        "Tegnsprogslærer",
        "Energiingeniør",
        "Dagtilbudsleder",
        "Vuggestueleder",
        "Plejehjemsleder",
        "Kommunikationskoordinator",
        "Brandchef",
        "Flysikkerhedschef",
        "Miljø- og sikkerhedschef",
        "Bibliotekschef",
        "Museumsleder",
        "Kunstnerisk leder",
        "Kundeservicechef",
        "Rigsarkivar",
        "Flymekaniker",
        "Skibsmekaniker",
        "Entreprenørmaskinemekaniker",
        "Kranmekaniker",
        "Industrimekaniker",
        "Cykelmekaniker",
        "Skorstensfejer",
        "Industrilakerer",
        "Autolakerer",
        "Murer",
        "Stenhugger",
        "Betonmager",
        "Køkkenmontør",
        "Tømrer",
        "Skov- og naturteknikerelev",
        "Lægemiddelkonsulent",
        "Bevægelsespædagog",
        "Ernæringsassistent",
        "Ungdomsskolelærer",
        "PAU-elev",
        "IT-underviser",
        "VUC-lærer",
        "Uddannelses- og erhvervsvejleder",
        "Finansrådgiver",
        "Investeringsrådgiver",
        "Musiklærer",
        "Hotelchef",
        "Butikschef",
        "Regionschef",
        "Teaterteknikerelev",
        "Speditørelev",
        "IT-supporterelev",
        "Politielev",
        "Vindmølleoperatørelev",
        "Gartnerelev",
        "Ortopædielev",
        "Fotografelev",
        "Film- og tvproduktionselev",
        "Procesoperatørelev",
        "Optikerelev",
        "Radio- og TV-fagteknikerelev",
        "Handelselev",
        "Elektronikoperatørelev",
        "Toldelev",
        "Plastmagerelev",
        "Social- og sundhedshjælperelev",
        "Grafikerelev",
        "Forsikringselev",
        "Revisorelev",
        "Shippingelev",
        "Regnskabselev",
        "Tjenerelev",
        "Finmekanikerelev",
        "Oliefyrsteknikerelev",
        "Urmagerelev",
        "Redderelev",
        "Teleteknikerelev",
        "Industrioperatørelev",
        "Landbrugselev",
        "Kosmetologelev",
        "Asfaltørelev",
        "Kontorelev",
        "Fitnessinstruktørelev",
        "Møbelsnedkerelev",
        "Serviceassistentelev",
        "Mejerielev",
        "Ernæringsassistentelev",
        "Neurofysiologiassistentelev",
        "Kostumier",
        "Buntmager",
        "Parykmager",
        "Skrædder",
        "Skomager",
        "Bore- og udvindingsarbejder",
        "Offshorearbejder",
        "Ordrebehandler",
        "Reservedelsekspedient",
        "Oldfrue",
        "Vicevært",
        "Ledsager",
        "Bedemandsassistent",
        "Bedemand",
        "Graver",
        "Kosmetolog",
        "Stylist",
        "Negletekniker",
        "Massør",
        "Tekstildesigner",
        "Kostumedesigner",
        "Institutleder på universitet",
        "Rektor",
        "Information- og videnchef IT",
        "Dokumentationsmedarbejder",
        "Efterskolelærer",
        "Dagplejer",
        "Yogalærer",
        "Dommerfuldmægtig",
        "Hotelmedarbejder",
        "Dagplejeleder",
        "Kordegn",
        "FGU-lærer",
        "Værkstedsassistent",
        "Økonoma",
        "Artist",
        "Væksthusgartner",
        "Gartneriarbejder",
        "Chef for gartneriproduktion",
        "Anlægsgartner",
        "Staldmester",
        "Støberitekniker",
        "Skibsbygger",
        "Svejser",
        "Klejnsmed",
        "Laboratorieleder",
        "Skovfoged",
        "Fiskeassistent",
        "Fisker",
        "Skytte",
        "Landmand",
        "Pelsdyravler",
        "Fængselsfunktionær",
        "Livredder",
        "Nødhjælpsarbejder",
        "Parkeringsvagt",
        "Kældermester",
        "Fødevareinspektør",
        "Grossist",
        "Varemægler",
        "Skibsfører",
        "Lods",
        "Skibsmaskinist",
        "Maskinmester",
        "Maskinassistent",
        "Mejeritekniker",
        "Produktionsteknolog",
        "Produktionsleder",
        "Værkfører",
        "Fysiker",
        "Astronom",
        "Metrolog",
        "Meteorolog",
        "Kemiker",
        "Geofysiker",
        "Geolog",
        "Statistiker",
        "Aktuar",
        "Demograf",
        "Matematiker",
        "Farmakolog",
        "Biolog",
        "Skovbrugsrådgiver",
        "Landbrugskonsulent",
        "Agronom",
        "Sagsadministrator",
        "Detektiv",
        "Kontormedhjælper",
        "Sekretær",
        "Tasteoperatør",
        "Bankassistent",
        "Croupier",
        "Av tekniker",
        "Tekniker radio- og TV-udsendelser",
        "Webmaster",
        "Garderobeassistent",
        "Butiksdetektiv",
        "Beklædningsdesigner",
        "Psykoterapeut",
        "Klinisk psykolog",
        "Produktionsingeniør",
        "Regionsdirektør",
        "Havearkitekt",
        "Salgs- og kundeansvarlig",
        "Systemadministrator",
        "IT-sikkerhedskonsulent",
        "Eventmanager",
        "Eventassistent",
        "Ejendomsadministrator",
        "Ejendomsmægler",
        "Reklamekonsulent",
        "Auktionsleder",
        "Musiker",
        "Danser",
        "Koreograf",
        "Kirketjener",
        "Driftschef",
        "Chefkonsulent",
        "Turismechef",
        "Brandinspektør",
        "Testingeniør",
        "Materialetekniker",
        "Kemiingeniør",
        "Økonomichef",
        "Cykelhandler",
        "Bagermester",
        "Politifuldmægtig",
        "Musikterapeut",
        "Kvalitetsingeniør",
        "Hundetræner",
        "Beslagsmed",
        "Teatermedarbejder",
        "Scenefunktionær",
        "Sikkerhedschef",
        "Plade- og konstruktionssmed",
        "Smed",
        "Finmekaniker",
        "Værktøjsmager",
        "Modelsnedker",
        "Låsesmed",
        "Hundefører",
        "Medarbejder på et dyreinternat",
        "Kørelærer",
        "Instrumentbygger",
        "Lydtekniker",
        "Tandklinikassistentelev",
        "Museumsmedhjælper",
        "Bådebyggerlærling",
        "Teknisk isolatørelev",
        "VVS-montør",
        "Blikkenslager",
        "Galvanisør",
        "Bådebygger",
        "Lastvognsmekaniker",
        "Knallertmekanikerlærling",
        "Laboratorietekniker",
        "Skibsmontør",
        "Manuskriptforfatter",
        "Teknisk kommunikator",
        "Vulkanisør",
        "Veterinærsygeplejerske",
        "Inseminør",
        "Drejer",
        "CNC-operatør",
        "Jern- og metalsliber",
        "Karosserismed",
        "Automekaniker",
        "Dækmontør",
        "Mekaniker",
        "Filmklipper",
        "Producer",
        "Skuespiller",
        "Jordbrugsteknolog",
        "Miljøtekniker",
        "Kort- og landmålingstekniker",
        "Fræser",
        "Transportchef",
        "Porcelænsmaler",
        "Robottekniker",
        "Personalechef",
        "Programchef",
        "Chefstrateg",
        "Facility manager",
        "Administrationschef",
        "Kvalitetschef",
        "Kontorfuldmægtig",
        "Advokatsekretær",
        "Direktionssekretær",
        "Redaktionssekretær",
        "Lægesekretær",
        "Administrativ lægesekretær",
        "Tolder",
        "Teletekniker",
        "Elektrofagtekniker",
        "Pottemager",
        "Glarmester",
        "Glasmager",
        "Skiltemaler",
        "Klaverstemmer",
        "Kranfører",
        "Truckfører",
        "Sadelmager",
        "Trykkeriarbejder",
        "Tekstiltrykker",
        "Elektriker",
        "Dirigent",
        "Korsanger",
        "Ligestillings- og inklusionschef",
        "Akupunktør",
        "Orgelbygger",
        "Personlig træner",
        "Forlystelsesmedarbejder",
        "Renseriassistent",
        "Redaktionschef",
        "Distributionschef",
        "Lagerchef",
        "Import- og eksportchef",
        "Supply chain manager",
        "Elektronikarbejder",
        "Lokomotivfører",
        "Togklargører",
        "Taxichauffør",
        "Risikoanalytiker",
        "Værdipapiranalytiker",
        "Forsikringsanalytiker",
        "Investeringsanalytiker",
        "Sceneinstruktør",
        "Caster",
        "Filminstruktør",
        "Stilladsmontør",
        "Nedriver",
        "Brandmand",
        "Tagdækker",
        "Stukkatør",
        "Isolatør",
        "Kloakrørlægger",
        "Kloakmester",
        "VVS-installatør",
        "Gastekniker",
        "HVAC-tekniker",
        "Arbejdsmiljøkonsulent",
        "Fysioterapeut",
        "Ernærings- og sundhedskonsulent",
        "Audiolog",
        "Logopæd",
        "Øjenlæge",
        "Radiograf",
        "Kiropraktor",
        "Ergoterapeut",
        "Elektroingeniør",
        "Fodterapeut",
        "Alternativ behandler",
        "Lektor",
        "Oversygeplejerske",
        "Specialsygeplejerske",
        "Sygeplejerske",
        "Elektronikingeniør",
        "Telekommunikationsingeniør",
        "Arkitekt",
        "Landskabsarkitekt",
        "Industriel designer",
        "Vaskeriassistent",
        "Bryggeriarbejder",
        "Datalog",
        "Psykiatrisk sygeplejerske",
        "Ortopædist",
        "Designteknolog",
        "Skibsmægler",
        "Medicotekniker",
        "Finanschef",
        "Regnskabschef",
        "Filmfotograf",
        "Guitarbygger",
        "Frisør inden for teater- og TV-branchen",
        "Hundefrisør",
        "Skilærer",
        "Misbrugsbehandler",
        "VVS-tekniker",
        "Maskinkonstruktør",
        "Skibsingeniør",
        "Lægesekretærelev",
        "Social- og sundhedsassistentelev",
        "Filmklipperelev",
        "Laborantelev",
        "Elektronikfagtekniker-elev",
        "Finanselev",
        "Kokkeelev",
        "Guld- og sølvsmedelev",
        "Maskinsnedkerelev",
        "Teknisk designerelev",
        "Uddannelsesleder",
        "Kørselsleder",
        "Greenkeeper",
        "Kunsthåndværker",
        "Neurofysiologiassistent",
        "Ministerialbetjent",
        "Sekretariatschef",
        "Plejehjemsmedhjælper",
        "Psykomotorisk terapeut",
        "Sundhedsplejerske",
        "TV-producer",
        "Sejlmager",
        "Smørrebrødsjomfru",
        "Sanglærer",
        "Rengøringsassistent",
        "Vinduespudser",
        "Bademester",
        "Maskinfører",
        "Buschauffør",
        "Procesoperatør",
        "Bygningsmaler",
        "Flisemontør",
        "Gulvlægger",
        "Tæppemontør",
        "Hospitalsserviceassistent",
        "Arkivmedarbejder",
        "HR-assistent",
        "Korrespondent",
        "Purser",
        "Rideskoleassistent",
        "Dyrepasser",
        "Køkkenmedhjælper",
        "Opvasker",
        "Omdeler",
        "Renovationsarbejder",
        "Gadefejer",
        "Måleraflæser",
        "Pizzabager",
        "Fastfood ekspedient",
        "Butiksmedhjælper",
        "Landbrugsmedhjælper",
        "Gartner",
        "Skovarbejder",
        "Dambrugsarbejder",
        "Politiinspektør",
        "Speditionsleder",
        "Bygningsingeniør",
        "Energikonsulent",
        "Elektronikfagtekniker",
        "Lingvist",
        "Tegnsprogstolk",
        "Oversætter",
        "Tolk",
        "Journalist",
        "Dramaturg",
        "Forlagsredaktør",
        "Advokat",
        "Dommer",
        "Notar",
        "Jurist",
        "Produktudvikler",
        "Industritekniker",
        "Laboratorieassistent",
        "Biomediciner",
        "Apotekerassistent",
        "Apotekstekniker",
        "Ortopædiingeniør",
        "Klinisk tandtekniker",
        "Dyreklinikassistent",
        "Flyveleder",
        "Flyveklarerer",
        "Pilot",
        "Rejsekonsulent",
        "Trafikassistent",
        "Billetsælger",
        "Rejsebureaumedarbejder",
        "Medarbejder på turistkontor",
        "Inkassomedarbejder",
        "Specialtandlæge",
        "Dyrlæge",
        "Tandlæge",
        "Apoteker",
        "CSR-ansvarlig",
        "Projektleder",
        "Afdelingsleder",
        "Salgsdirektør",
        "Bygningskonstruktør",
        "Afdelingschef",
        "Fodermester",
        "Havneassistent",
        "Farmaceut",
        "Artdirector assistent",
        "Professor",
        "Faglærer",
        "Automontør",
        "Familieplejer",
        "Blomsterdekoratør",
        "Sundhedsøkonom",
        "Bilsynsassistent",
        "Badeassistent",
        "Businesscontroller",
        "Specialkonsulent",
        "FVU-lærer",
        "Bageriarbejder",
        "Ridelærer",
        "Fitness-instruktør",
        "Optiker",
        "Fotograf",
        "Fotojournalist",
        "Køkkenchef",
        "Regissør",
        "Salgschef",
        "Elinstallatør",
        "Skolekonsulent",
        "Læge",
        "Byggesagsbehandler",
        "Økologikonsulent",
        "Restaurantchef",
        "Cater",
        "Adjunkt",
        "Faglig konsulent",
        "Forsorgsmedarbejder",
        "Pædagogisk konsulent",
        "Sygehuslæge",
        "Hospitalsmedhjælper",
        "Kirkesanger",
        "Kantineleder",
        "Fagkonsulent",
        "Handicaphjælper",
        "Aftenskolelærer",
        "Projektkoordinator",
        "Ligestillingskonsulent",
        "Brolæggerarbejde",
        "Bygningsstruktør",
        "Oliefyrstekniker",
        "Motorcykelmekaniker",
        "Buschaufførelev",
        "Minkfarmmedhjælper",
        "Procesteknolog",
        "Rengøringsassistent i transportmidler",
        "Butiks- og detailslagter",
        "Audiologiassistent",
        "Skiltemalerlærling",
        "Rengøringsassistent i kontor",
        "Ventilationstekniker",
        "Skibsassistent",
        "AV teknikerelev",
        "Højskolelærer",
        "Detailhandelselev",
        "Forretningsudvikler",
        "Vinkyper",
        "Kulturmedarbejder",
        "Zoneterapeut",
        "Styrmand",
        "Turistchef",
        "Anæstesisygeplejerske",
        "Støttepædagog",
        "Salgskonsulent",
        "Eventkoordinatorelev",
        "Bygningssnedker",
        "Finansmedarbejder",
        "Kursuskoordinator",
        "Automatiktekniker",
        "Bioanalytiker",
        "Klubpædagog",
        "Vagtcentralleder",
        "Flyteknikner",
        "Forsyningsoperatør",
        "Account manager",
        "Datatekniker",
        "Logistikchef",
        "Tale-hørelærer",
        "Plastmager",
        "IT-produktchef",
        "Erhvervsanalytiker",
        "Halinspektør",
        "Maskinoperatør",
        "Kommunikationsmedarbejder",
        "Anlægsstruktør",
        "Filmtekniker",
        "Elektronikfagteknikerelev",
        "Servicetekniker",
        "Mejeriingeniør",
        "Poder",
        "Advokatfuldmægtig",
        "Omsorgshjælper",
        "Kvalitetsmedarbejder",
        "Forlagskonsulent",
        "Flyteknikerlærling",
        "Skov- og naturtekniker",
        "Skolesekretær",
        "IT-produktejer",
        "Kontorassistent",
        "Udviklingskonsulent",
        "Pædagogisk faglig koordinator",
    ]



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    # Source: https://vi.wikipedia.org/wiki/Danh_s%C3%A1ch_c%C3%B4ng_ty_Vi%E1%BB%87t_Nam
    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{last_name}} và {{last_name}} {{company_suffix}}",
        "{{last_name}} và đối tác {{company_suffix}}",
    )

    company_suffixes = (
        "Công ty TNHH",
        "Công ty Cổ phần",
        "Doanh nghiệp tư nhân",
        "Công ty TNHH MTV",
        "Công ty Hợp danh",
        "Công ty Trách nhiệm hữu hạn",
        "Tập Đoàn",
    )

    def company_suffix(self) -> str:
        return self.random_element(self.company_suffixes)



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """Implement color provider for ``ka_GE`` locale."""

    all_colors = OrderedDict(
        (
            ("ანტიკური თეთრი", "#FAEBD7"),
            ("აკვამარინი", "#7FFFD4"),
            ("ლურჯი", "#F0FFFF"),
            ("ბეჟი", "#F5F5DC"),
            ("შავი", "#000000"),
            ("ცისფერი", "#0000FF"),
            ("საზღვაო ლურჯი", "#8A2BE2"),
            ("ყავისფერი", "#A52A2A"),
            ("შოკოლადისფერი", "#D2691E"),
            ("კორალისფერი", "#FF7F50"),
            ("ვერცხლისფერი", "#6495ED"),
            ("ჟოლოსფერი", "#DC143C"),
            ("მუქი ლურჯი", "#00008B"),
            ("მუქი ცისფერი", "#008B8B"),
            ("მუქი ნაცრისფერი", "#A9A9A9"),
            ("მუქი მწვანე", "#006400"),
            ("მუქი ხაკისფერი", "#BDB76B"),
            ("მუქი ნარინჯისფერი", "#FF8C00"),
            ("მუქი წითელი", "#8B0000"),
            ("მუქი ზღვისფერი", "#00CED1"),
            ("მუქი იასამნისფერი", "#9400D3"),
            ("მუქი ვარდისფერი", "#FF1493"),
            ("მკვდარი ნაცრისფერი", "#696969"),
            ("ფუქსია", "#FF00FF"),
            ("ოქროსფერი", "#FFD700"),
            ("ნაცრისფერი", "#808080"),
            ("მწვანე", "#008000"),
            ("ყვითელ-მწვანე", "#ADFF2F"),
            ("ინტენსიური ვარდისფერი", "#FF69B4"),
            ("ინდიგო", "#4B0082"),
            ("სპილოს ძვალი", "#FFFFF0"),
            ("ხაკისფერი", "#F0E68C"),
            ("ლავანდისფერი ვარდისფერი", "#FFF0F5"),
            ("ღია ლურჯი", "#ADD8E6"),
            ("ღია ცისფერი", "#E0FFFF"),
            ("ღია ნაცრისფერი", "#D3D3D3"),
            ("ღია მწვანე", "#90EE90"),
            ("ღია ვარდისფერი", "#FFB6C1"),
            ("ღია ცისფერი", "#87CEFA"),
            ("ღია ყვითელი", "#FFFFE0"),
            ("მეწამული", "#800000"),
            ("ნარინჯისფერი", "#FFA500"),
            ("ნარინჯისფერი წითელი", "#FF4500"),
            ("ღია მწვანე", "#98FB98"),
            ("ღია ზღვისფერი", "#AFEEEE"),
            ("ვარდისფერი", "#FFC0CB"),
            ("ქლიავისფერი", "#DDA0DD"),
            ("იასამნისფერი", "#800080"),
            ("წითელი", "#FF0000"),
            ("ზღვისფერი", "#2E8B57"),
            ("ვერცხლისფერი", "#C0C0C0"),
            ("თურქული ლურჯი", "#40E0D0"),
            ("იისფერი", "#EE82EE"),
            ("თეთრი", "#FFFFFF"),
            ("ყვითელი", "#FFFF00"),
            ("ყვითელ-მწვანე", "#9ACD32"),
            ("ბრინჯაოსფერი", "#CD7F32"),
            ("მსხლისფერი", "#D1E231"),
            ("თითბერისფერი", "#D5A642"),
            ("მანდარინისფერი", "#FF8800"),
            ("ფიჭვისფერი", "#01796F"),
            ("ზეთისხილისფერი", "#808000"),
        )
    )

    safe_colors = (
        "შავი",
        "მუქი წითელი",
        "მწვანე",
        "ხაკისფერი",
        "იასამნისფერი",
        "თურმანჯურა",
        "ცაცხვისფერი",
        "ცისფერი",
        "ვერცხლისფერი",
        "ნაცრისფერი",
        "ყვითელი",
        "ფუქსია",
        "თეთრი",
    )



from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}",
        "{{first_name}} {{last_name}}-{{last_name}}",
        "{{first_name_female}} {{last_name}} {{last_name}}",
        "{{prefix}} {{first_name}} {{last_name}}",
    )

    # extracted from https://www.bfs.admin.ch/bfs/it/home/statistiche/popolazione/nascite-decessi/nomi-svizzera.assetdetail.3243313.html # noqa E501
    first_names_male = (
        "Peter",
        "Hans",
        "Daniel",
        "Thomas",
        "Andreas",
        "Martin",
        "Markus",
        "Michael",
        "Christian",
        "Stefan",
        "Walter",
        "Urs",
        "Marco",
        "Bruno",
        "Patrick",
        "Werner",
        "René",
        "Marcel",
        "Beat",
        "Roland",
        "Kurt",
        "Josef",
        "David",
        "Simon",
        "Rolf",
        "Heinz",
        "Rudolf",
        "Paul",
        "Roger",
        "Christoph",
        "Ernst",
        "Pascal",
        "Adrian",
        "Lukas",
        "Marc",
        "Robert",
        "Reto",
        "Manuel",
        "Fabian",
        "Alfred",
        "Philipp",
        "Jürg",
        "Matthias",
        "Stephan",
        "Franz",
        "Anton",
        "André",
        "Alexander",
        "Samuel",
        "Jan",
        "Johann",
        "Luca",
        "Max",
        "Roman",
        "Mario",
        "Fritz",
        "Ulrich",
        "Dominik",
        "Karl",
        "Tobias",
        "Oliver",
        "Florian",
        "Antonio",
        "Benjamin",
        "Sandro",
        "Bernhard",
        "Jonas",
        "Felix",
        "Raphael",
        "Kevin",
        "Erich",
        "Fabio",
        "Jakob",
        "Sven",
        "Dario",
        "Giuseppe",
        "Remo",
        "Nicolas",
        "Albert",
        "Erwin",
        "Richard",
        "Nico",
        "Michel",
        "José",
        "Claudio",
        "Tim",
        "Noah",
        "Joel",
        "Heinrich",
        "Jörg",
        "Robin",
        "Sebastian",
        "Armin",
        "Guido",
        "Silvan",
        "Lars",
        "Ivan",
        "Julian",
        "Alois",
        "Francesco",
        "Sascha",
        "Dominic",
        "Johannes",
        "Georg",
        "Gabriel",
        "Manfred",
        "Herbert",
        "Otto",
        "Alessandro",
        "Gerhard",
        "Patrik",
        "Gian",
        "Mathias",
        "Leon",
        "Willi",
        "Eduard",
        "Nicola",
        "Hugo",
        "Ali",
        "Yves",
        "Elias",
        "Hermann",
        "Philippe",
        "Leo",
        "Emil",
        "Frank",
        "Dieter",
        "Friedrich",
        "Luis",
        "Giovanni",
        "Niklaus",
        "Alex",
        "Roberto",
        "Rafael",
        "Hanspeter",
        "Diego",
        "Nils",
        "Leandro",
        "Ramon",
        "Severin",
        "Salvatore",
        "Mike",
        "Alain",
        "Timo",
        "Carlos",
        "Arthur",
        "Yannick",
        "Eric",
        "Angelo",
        "Ivo",
        "Wolfgang",
        "Matteo",
        "Joël",
        "Andrin",
        "Pius",
        "Moritz",
        "Valentin",
        "Louis",
        "Wilhelm",
        "Renato",
        "Levin",
        "Silvio",
        "Willy",
        "Andrea",
        "Jonathan",
        "Jean",
        "Livio",
        "Loris",
        "Damian",
        "Theodor",
        "Michele",
        "Vincenzo",
        "Elia",
        "Ralph",
        "Klaus",
        "Eugen",
        "Mark",
        "Konrad",
        "Denis",
        "Norbert",
        "Lorenz",
        "Viktor",
        "Mehmet",
        "Marko",
        "Kilian",
        "Hans-Peter",
        "Cédric",
        "Ralf",
        "Aaron",
        "Maximilian",
        "Carlo",
        "Alessio",
        "Olivier",
        "Jürgen",
        "Luigi",
        "Philip",
        "Lucas",
        "Mauro",
        "Janis",
        "Cyrill",
        "Linus",
        "Davide",
        "Othmar",
        "Flavio",
        "Nino",
        "Arnold",
        "Nick",
        "Rainer",
        "Domenico",
        "Adolf",
        "Emanuel",
        "Oskar",
        "Ben",
        "Joshua",
        "Leonardo",
        "Franco",
        "Pierre",
        "John",
        "Gregor",
        "Fernando",
        "Marius",
        "Claude",
        "Edwin",
        "Colin",
        "Mustafa",
        "Pedro",
        "Stefano",
        "Sergio",
        "Dominique",
        "Juan",
        "Nikola",
        "Enrico",
        "Jens",
        "Daniele",
        "Thierry",
        "Jose",
        "Liam",
        "Francisco",
        "Ricardo",
        "Rico",
        "Christof",
        "Aleksandar",
        "Dennis",
        "Mohamed",
        "Joseph",
        "Charles",
        "Noel",
        "Miguel",
        "Laurin",
        "Milan",
        "Reinhard",
        "Lionel",
        "Dragan",
        "Hasan",
        "Paulo",
        "Edgar",
        "Silas",
        "Hubert",
        "Helmut",
        "Ibrahim",
        "Ruben",
        "Timon",
        "Vincent",
        "Christopher",
        "Finn",
        "Ronny",
        "Kaspar",
        "Mattia",
        "Lorenzo",
        "Pietro",
        "Björn",
        "Hansruedi",
        "Gottfried",
        "Joachim",
        "Benno",
        "Harald",
        "Jorge",
        "Cedric",
        "Nevio",
        "Paolo",
        "Gianluca",
        "Boris",
        "Kai",
        "Maurizio",
        "Steven",
        "Mischa",
        "Patric",
        "Zoran",
        "Mirco",
        "Marvin",
        "Dirk",
        "Benedikt",
        "Uwe",
        "Hans-Rudolf",
        "Maurice",
        "Massimo",
        "Hansjörg",
        "Jeremy",
        "Niklas",
        "Ahmet",
        "Fridolin",
        "Dejan",
        "Goran",
        "Micha",
        "Mohammad",
        "Ronald",
        "Bernd",
        "Mirko",
        "Erik",
        "Jason",
        "Tiago",
        "Riccardo",
        "Jérôme",
        "Igor",
        "Siegfried",
        "Pasquale",
        "Andri",
        "Tom",
        "Ueli",
        "Amir",
        "Cyril",
        "Adriano",
        "Alberto",
        "Ferdinand",
        "Justin",
        "Raffael",
        "Julien",
        "Lenny",
        "Luka",
        "Marcus",
        "Pirmin",
        "Janik",
        "Julius",
        "Meinrad",
        "Adam",
        "James",
        "Hüseyin",
        "Alexandre",
        "Rocco",
        "Luc",
        "Victor",
        "João",
        "Andres",
        "Luan",
        "Flurin",
        "Filip",
        "Ismail",
        "Danilo",
        "Laurent",
        "Raffaele",
        "Ahmed",
        "Günter",
        "Joao",
        "Rui",
        "Xaver",
        "Fabrizio",
        "William",
        "Vito",
        "Miroslav",
        "Lino",
        "Albin",
        "Jean-Pierre",
        "Basil",
        "Till",
        "Horst",
        "Romeo",
        "Aldo",
        "Murat",
        "Harry",
        "Alfons",
        "Pablo",
        "Bernard",
        "Noé",
        "Luciano",
        "August",
        "Levi",
        "Nando",
        "Fabrice",
        "Raymond",
        "Jamie",
        "Georges",
        "Steffen",
        "Serge",
        "Cristian",
        "Samir",
        "António",
        "Marlon",
        "Omar",
        "Lian",
        "Oscar",
        "Yanick",
        "Armando",
        "Nikolaus",
        "Dylan",
        "Hannes",
        "Sacha",
        "Nuno",
        "Toni",
        "Dino",
        "Elmar",
        "Arno",
        "Joaquim",
        "Sasa",
        "Henry",
        "Vladimir",
        "Arben",
        "Ryan",
        "Bekim",
        "Milos",
        "Giorgio",
        "Ludwig",
        "Leonard",
        "Adnan",
        "Gilbert",
        "Yannik",
        "Aron",
        "Iwan",
        "Maik",
        "Dimitri",
        "Erhard",
        "François",
        "Gabriele",
        "Sami",
        "Elio",
        "Antonino",
        "Fynn",
        "Simone",
        "Andrew",
        "Alan",
        "Nenad",
        "Frédéric",
        "Etienne",
        "Janick",
        "Steve",
        "Christophe",
        "Gianni",
        "Urban",
        "Anthony",
        "Deniz",
        "Jon",
        "Alejandro",
        "Axel",
        "Ian",
        "Theo",
        "Andrej",
        "Brian",
        "Lucien",
        "Gino",
        "Clemens",
        "Yanik",
        "Adem",
        "Emir",
        "Tino",
        "Miro",
        "Enis",
        "Gregory",
        "Danijel",
        "Osman",
        "Michal",
        "Carmine",
        "Orlando",
        "Enes",
        "Giuliano",
        "Timothy",
        "Fredy",
        "Besnik",
        "Vitor",
        "Holger",
        "Kim",
        "Eduardo",
        "Petar",
        "Jacques",
        "Karim",
        "Darko",
        "Gustav",
        "Emilio",
        "Mateo",
        "Alban",
        "Marek",
        "Oswald",
        "Noël",
        "Donato",
        "Mohammed",
        "Roy",
        "Kay",
        "Nathan",
        "Enea",
        "Silvano",
        "Josip",
        "Valerio",
        "Artur",
        "Besim",
        "Mika",
        "Torsten",
        "Romano",
        "Heiko",
        "Yusuf",
        "Chris",
        "Naim",
        "Burim",
        "Gaetano",
        "Hans-Ulrich",
        "Olaf",
        "Maurus",
        "Volker",
        "Jean-Claude",
        "Henri",
        "Nik",
        "Rodrigo",
        "Florin",
        "Mael",
        "Amar",
        "Agron",
        "Muhamed",
        "Tristan",
        "Valon",
        "Ahmad",
        "Ilir",
        "Javier",
        "Lorin",
        "Yanis",
        "Fatmir",
        "Bajram",
        "Carmelo",
        "Agim",
        "Enzo",
        "Moreno",
        "Cornel",
        "Andy",
        "Jeton",
        "Blerim",
        "Bojan",
        "Federico",
        "Attila",
        "Juri",
        "Tomas",
        "Valentino",
        "Ismet",
        "Jannik",
        "Ruedi",
        "Afrim",
        "Yannic",
        "Ramadan",
        "Alfredo",
        "Josua",
        "Cosimo",
        "Gerardo",
        "Bastian",
        "Filippo",
        "Raoul",
        "Halil",
        "Yann",
        "Georgios",
        "Jannis",
        "Nicholas",
        "Sean",
        "Wilfried",
        "Günther",
        "Dusan",
        "Beda",
        "Gerold",
        "Gottlieb",
        "Filipe",
        "Ilija",
        "Carl",
        "Ardian",
        "Marcello",
        "Enver",
        "Dean",
        "Dion",
        "Tenzin",
        "Zeljko",
        "Carsten",
        "Diogo",
        "Alen",
        "Egon",
        "Aurel",
        "Yannis",
        "Edin",
        "Hans-Jörg",
        "Tomislav",
        "Mohamad",
        "Bujar",
        "Raul",
        "Slobodan",
        "Driton",
        "Maxim",
        "Francis",
        "Hansueli",
        "Ivica",
        "Nelson",
        "Emanuele",
        "Konstantin",
        "Fred",
        "Naser",
        "Gerd",
        "Kristian",
        "Selim",
        "Corsin",
        "Dietmar",
        "George",
        "Piotr",
        "Giacomo",
        "Ingo",
        "Andre",
        "Malik",
        "Lothar",
        "Jochen",
        "Sinan",
        "Thorsten",
        "Tiziano",
        "Gilles",
        "Avni",
        "Jann",
        "Lio",
        "Niels",
        "Emmanuel",
        "Leonhard",
        "Lorik",
        "Aurelio",
        "Gion",
        "Liridon",
        "Marino",
        "Can",
        "Kenan",
        "Ewald",
        "Stéphane",
        "Dalibor",
        "Jozef",
        "Noe",
        "Bryan",
        "Dan",
        "Santiago",
        "Damiano",
        "Arian",
        "Rosario",
        "Giancarlo",
        "Nathanael",
        "Emre",
        "Stephen",
        "Hassan",
        "Jovan",
        "Egzon",
        "Reinhold",
        "Tomasz",
        "Vittorio",
        "Patrice",
        "Tibor",
        "Jost",
        "Elvis",
        "Lean",
        "Henrik",
        "Musa",
        "Noa",
        "Udo",
        "Almir",
        "Van",
        "Dietrich",
        "Mladen",
        "Armend",
        "Arlind",
        "Milo",
        "Arsim",
        "Bashkim",
        "Dimitrios",
        "Matthew",
        "Ömer",
        "Abdullah",
        "Hakan",
        "Gerald",
        "Tommaso",
        "Joris",
        "Damir",
        "Vinzenz",
        "Marcos",
        "Raphaël",
        "Ennio",
        "Melvin",
        "Leander",
        "Kuno",
        "Massimiliano",
        "Maël",
        "Anto",
        "Branko",
        "Fadil",
        "Kemal",
        "Muhammed",
        "Hendrik",
        "Pawel",
        "Jeremias",
        "Léon",
        "Leano",
        "Rémy",
        "Giulio",
        "Muhamet",
        "Lulzim",
        "Konstantinos",
        "Pavel",
        "Rinaldo",
        "Omer",
        "Simeon",
        "Gian-Luca",
        "Maurin",
        "Antoine",
        "Frederik",
        "Janic",
        "Faton",
        "Marcin",
        "Sébastien",
        "Cem",
        "Curdin",
        "Endrit",
        "Nemanja",
        "Karsten",
        "Renzo",
        "Jerome",
        "Krzysztof",
        "Jeffrey",
        "Sebastiano",
        "Ernesto",
        "Lazar",
        "Ramazan",
        "Gérard",
        "Ajan",
        "Emin",
        "Ioannis",
        "Jesus",
        "Alfonso",
        "Yasin",
        "Jaron",
        "Alexis",
        "Orhan",
        "Artan",
        "Morris",
        "Angel",
        "Janosch",
        "Rene",
        "Shaban",
        "Jakub",
        "Loïc",
        "Kristijan",
        "Enrique",
        "Skender",
        "Gianfranco",
        "Mathieu",
        "Xavier",
        "Mathis",
        "Didier",
        "Arif",
        "Hamza",
        "Jacob",
        "Leart",
        "Laszlo",
        "Predrag",
        "Mentor",
        "Wendelin",
        "Luís",
        "Constantin",
        "Erion",
        "Berat",
        "Dardan",
        "Melchior",
        "Serkan",
        "Dorian",
        "Eren",
        "Fatih",
        "Luzius",
        "Nebojsa",
        "Metin",
        "Diar",
        "Rino",
        "Ekrem",
        "Isa",
        "Jetmir",
        "Edward",
        "Nikolaos",
        "Gazmend",
        "Haris",
        "Kian",
        "Ensar",
        "Mirsad",
        "Danny",
        "Senad",
        "Donat",
        "Bilal",
        "Ron",
        "Nael",
        "Guy",
        "Julio",
        "Kujtim",
        "Kushtrim",
        "Lutz",
        "Balthasar",
        "Rouven",
        "Lias",
        "Neil",
        "Abraham",
        "Magnus",
        "Sérgio",
        "Hansjürg",
        "Said",
        "Ismael",
        "Detlef",
        "Umberto",
        "Admir",
        "Jayden",
        "Jaime",
        "Karl-Heinz",
        "Tomás",
        "Florim",
        "Achim",
        "Devin",
        "Maxime",
        "Fitim",
        "Jean-Marc",
        "Rayan",
        "Sadik",
        "Tarik",
        "Abdul",
        "Jack",
        "Mergim",
        "Nelio",
        "Sam",
        "Flamur",
        "Ignaz",
        "Samuele",
        "Tony",
        "Petr",
        "Waldemar",
        "Arda",
        "Ardit",
        "Lukasz",
        "Milorad",
        "Nicolai",
        "Ramiz",
        "Aziz",
        "Kamil",
        "Rinor",
        "Safet",
        "Piero",
        "Erkan",
        "Niko",
        "Zsolt",
        "Ernest",
        "Miodrag",
        "Alvaro",
        "Astrit",
        "Edmund",
        "Jules",
        "Cristiano",
        "Ivano",
        "Kenneth",
        "Saverio",
        "Semir",
        "Burak",
        "Theophil",
        "Altin",
        "Andrzej",
        "Jonah",
        "Jiri",
        "Salih",
        "Zoltán",
        "Ferenc",
        "Grzegorz",
        "Irfan",
        "Johan",
        "Kaan",
        "Süleyman",
        "Hussein",
        "Rexhep",
        "Besart",
        "Janos",
        "Labinot",
        "Onur",
        "Stjepan",
        "Domenic",
        "Siro",
        "Abel",
        "Florent",
        "Christos",
        "Swen",
        "Branislav",
        "Mato",
        "Amin",
        "Matej",
        "Slavko",
        "Jusuf",
        "Luke",
        "Slavisa",
        "Erol",
        "Gabor",
        "Jasmin",
        "Visar",
        "Sinisa",
        "Isidor",
        "Merlin",
        "Claus",
        "Marin",
        "Zoltan",
        "Muhammad",
        "Neo",
        "Zeno",
        "Istvan",
        "Adis",
        "Edon",
        "Gil",
        "Leopold",
        "Hartmut",
        "Raimund",
        "Ken",
        "Csaba",
        "Kerim",
        "Norman",
        "Lucio",
        "László",
        "Marjan",
        "Damjan",
        "Eugenio",
        "Domingos",
        "Reiner",
        "Augusto",
        "Gzim",
        "Nazmi",
        "Laurenz",
        "Zlatko",
        "Jaroslav",
        "Nevin",
        "Biagio",
        "Felice",
        "Balz",
        "Boban",
        "Marcelo",
        "Caspar",
        "Ledion",
        "Rodolfo",
        "Aldin",
        "Matti",
        "Remzi",
        "Ljubisa",
        "Til",
        "Péter",
        "Umut",
        "Baris",
        "Lirim",
        "Mehdi",
        "Edmond",
        "Gonçalo",
        "Jasin",
        "Niclas",
        "Jordan",
        "Mahmoud",
        "Stanislav",
        "Cornelius",
        "Jona",
        "Khaled",
        "Quentin",
        "Gökhan",
        "Imer",
        "Volkan",
        "Harun",
        "Miran",
        "Damien",
        "Gennaro",
        "Jari",
        "Marian",
        "Rüdiger",
        "Albrecht",
        "Mile",
        "Thiago",
        "Yvan",
        "Alwin",
        "Gani",
        "Mahmut",
        "Pero",
        "Evan",
        "Fisnik",
        "Idriz",
        "Sergej",
        "Sabri",
        "Felipe",
        "István",
        "Dave",
        "Hans-Jürgen",
        "Jean-Luc",
        "Kastriot",
        "Mariusz",
        "Arne",
        "Faruk",
        "Gebhard",
        "German",
        "Tamás",
        "Anes",
        "Arbnor",
        "Mats",
        "Drilon",
        "Fábio",
        "Mihajlo",
        "Sedat",
        "Tahir",
    )

    # extracted from https://www.bfs.admin.ch/bfs/it/home/statistiche/popolazione/nascite-decessi/nomi-svizzera.assetdetail.3243318.html # noqa E501
    first_names_female = (
        "Maria",
        "Anna",
        "Ursula",
        "Ruth",
        "Elisabeth",
        "Sandra",
        "Monika",
        "Claudia",
        "Verena",
        "Nicole",
        "Barbara",
        "Silvia",
        "Andrea",
        "Marie",
        "Daniela",
        "Christine",
        "Karin",
        "Marianne",
        "Erika",
        "Margrit",
        "Brigitte",
        "Susanne",
        "Rita",
        "Laura",
        "Sarah",
        "Katharina",
        "Rosmarie",
        "Esther",
        "Heidi",
        "Anita",
        "Manuela",
        "Rosa",
        "Doris",
        "Sonja",
        "Beatrice",
        "Yvonne",
        "Gertrud",
        "Jacqueline",
        "Sara",
        "Irene",
        "Ana",
        "Franziska",
        "Cornelia",
        "Fabienne",
        "Gabriela",
        "Patricia",
        "Martina",
        "Julia",
        "Edith",
        "Eva",
        "Isabelle",
        "Sabrina",
        "Nathalie",
        "Alexandra",
        "Corinne",
        "Angela",
        "Melanie",
        "Alice",
        "Nadine",
        "Jessica",
        "Denise",
        "Elena",
        "Vanessa",
        "Simone",
        "Anne",
        "Regula",
        "Susanna",
        "Carmen",
        "Sophie",
        "Caroline",
        "Emma",
        "Nina",
        "Tanja",
        "Catherine",
        "Sabine",
        "Lara",
        "Petra",
        "Lea",
        "Céline",
        "Jasmin",
        "Therese",
        "Stefanie",
        "Johanna",
        "Nadia",
        "Tamara",
        "Chantal",
        "Martha",
        "Michelle",
        "Christina",
        "Marina",
        "Adelheid",
        "Dora",
        "Monique",
        "Rahel",
        "Hedwig",
        "Lisa",
        "Janine",
        "Pia",
        "Anja",
        "Elsbeth",
        "Madeleine",
        "Eveline",
        "Judith",
        "Diana",
        "Françoise",
        "Charlotte",
        "Maja",
        "Eliane",
        "Renate",
        "Christiane",
        "Michèle",
        "Jennifer",
        "Bettina",
        "Chiara",
        "Bernadette",
        "Aline",
        "Carla",
        "Helena",
        "Brigitta",
        "Mirjam",
        "Theresia",
        "Astrid",
        "Nadja",
        "Jana",
        "Selina",
        "Priska",
        "Lena",
        "Stephanie",
        "Lucia",
        "Linda",
        "Regina",
        "Agnes",
        "Olivia",
        "Sonia",
        "Valérie",
        "Klara",
        "Ramona",
        "Lina",
        "Elsa",
        "Helene",
        "Monica",
        "Iris",
        "Hanna",
        "Valentina",
        "Annemarie",
        "Elisa",
        "Margrith",
        "Dominique",
        "Beatrix",
        "Cristina",
        "Paula",
        "Magdalena",
        "Livia",
        "Sofia",
        "Patrizia",
        "Liliane",
        "Nelly",
        "Marion",
        "Ida",
        "Alina",
        "Isabel",
        "Vera",
        "Stéphanie",
        "Giulia",
        "Leonie",
        "Jeannette",
        "Christa",
        "Alessia",
        "Véronique",
        "Myriam",
        "Emilie",
        "Olga",
        "Nora",
        "Julie",
        "Sylvia",
        "Margaretha",
        "Claudine",
        "Marlise",
        "Miriam",
        "Sibylle",
        "Sylvie",
        "Lydia",
        "Katja",
        "Lorena",
        "Jolanda",
        "Rebecca",
        "Mia",
        "Irma",
        "Larissa",
        "Luana",
        "Martine",
        "Deborah",
        "Francesca",
        "Veronika",
        "Isabella",
        "Noemi",
        "Ingrid",
        "Frieda",
        "Suzanne",
        "Liselotte",
        "Michaela",
        "Florence",
        "Evelyne",
        "Hildegard",
        "Corina",
        "Danielle",
        "Laurence",
        "Carole",
        "Milena",
        "Cécile",
        "Mara",
        "Luzia",
        "Sandrine",
        "Gisela",
        "Simona",
        "Mélanie",
        "Béatrice",
        "Marta",
        "Antonia",
        "Erna",
        "Gabriele",
        "Katrin",
        "Kathrin",
        "Melissa",
        "Camille",
        "Adriana",
        "Fiona",
        "Lucie",
        "Natalie",
        "Teresa",
        "Renata",
        "Josiane",
        "Sophia",
        "Clara",
        "Luisa",
        "Silvana",
        "Jeannine",
        "Pascale",
        "Hélène",
        "Emilia",
        "Joëlle",
        "Gabriella",
        "Maya",
        "Marianna",
        "Ines",
        "Léa",
        "Claire",
        "Marisa",
        "Sina",
        "Lia",
        "Paola",
        "Mathilde",
        "Sabina",
        "Alessandra",
        "Ivana",
        "Anne-Marie",
        "Elvira",
        "Bianca",
        "Samira",
        "Cindy",
        "Amélie",
        "Chloé",
        "Kim",
        "Victoria",
        "Annette",
        "Angelina",
        "Dorothea",
        "Antoinette",
        "Tina",
        "Tania",
        "Angelika",
        "Valeria",
        "Flavia",
        "Margaritha",
        "Rachel",
        "Marguerite",
        "Jeanne",
        "Yvette",
        "Natalia",
        "Alicia",
        "Giovanna",
        "Mireille",
        "Liliana",
        "Pauline",
        "Seraina",
        "Elodie",
        "Ariane",
        "Helga",
        "Zoé",
        "Natascha",
        "Muriel",
        "Francine",
        "Joana",
        "Melina",
        "Aurélie",
        "Thi",
        "Giuseppina",
        "Tatiana",
        "Margareta",
        "Louise",
        "Marija",
        "Debora",
        "Salome",
        "Viviane",
        "Fanny",
        "Katia",
        "Carolina",
        "Irina",
        "Bertha",
        "Marlene",
        "Noémie",
        "Amanda",
        "Sarina",
        "Marlies",
        "Lilian",
        "Irène",
        "Laetitia",
        "Kristina",
        "Jasmine",
        "Ella",
        "Jenny",
        "Gabrielle",
        "Carmela",
        "Manon",
        "Helen",
        "Fatima",
        "Stefania",
        "Virginie",
        "Ladina",
        "Jelena",
        "Berta",
        "Antonella",
        "Rebekka",
        "Audrey",
        "Anaïs",
        "Tatjana",
        "Annina",
        "Margot",
        "Carina",
        "Samantha",
        "Evelyn",
        "Annamarie",
        "Tiziana",
        "Arlette",
        "Emily",
        "Kerstin",
        "Svenja",
        "Caterina",
        "Christelle",
        "Saskia",
        "Elin",
        "Lilly",
        "Anouk",
        "Rose",
        "Fatma",
        "Lynn",
        "Elina",
        "Colette",
        "Josette",
        "Leila",
        "Gerda",
        "Susana",
        "Geneviève",
        "Désirée",
        "Naomi",
        "Stella",
        "Romina",
        "Delphine",
        "Aurora",
        "Estelle",
        "Juliette",
        "Tabea",
        "Anina",
        "Thérèse",
        "Mariana",
        "Beatriz",
        "Hilda",
        "Lotti",
        "Séverine",
        "Delia",
        "Ronja",
        "Gina",
        "Mila",
        "Antonietta",
        "Veronica",
        "Aleksandra",
        "Gisèle",
        "Lidia",
        "Natacha",
        "Laure",
        "Pamela",
        "Rosemarie",
        "Marie-Louise",
        "Jael",
        "Eleonora",
        "Zoe",
        "Franca",
        "Hannah",
        "Yolanda",
        "Birgit",
        "Amina",
        "Leandra",
        "Elise",
        "Alma",
        "Anastasia",
        "Marlis",
        "Fernanda",
        "Irmgard",
        "Micheline",
        "Elfriede",
        "Selma",
        "Ilona",
        "Danièle",
        "Justine",
        "Magali",
        "Georgette",
        "Graziella",
        "Cynthia",
        "Cäcilia",
        "Loredana",
        "Géraldine",
        "Sylviane",
        "Heidy",
        "Alexia",
        "Mary",
        "Ingeborg",
        "Emine",
        "Yara",
        "Ursina",
        "Marlène",
        "Morgane",
        "Michela",
        "Katarina",
        "Marine",
        "Ulrike",
        "Daria",
        "Bruna",
        "Jasmina",
        "Mira",
        "Soraya",
        "Juliana",
        "Marlyse",
        "Agnès",
        "Carine",
        "Gloria",
        "Alena",
        "Svetlana",
        "Josefina",
        "Annelise",
        "Myrta",
        "Roberta",
        "Pierrette",
        "Celine",
        "Annika",
        "Mirjana",
        "Andrée",
        "Célia",
        "Serena",
        "Christel",
        "Susan",
        "Jocelyne",
        "Renée",
        "Vesna",
        "Andreia",
        "Elizabeth",
        "Cinzia",
        "Karen",
        "Cecilia",
        "Karine",
        "Marlen",
        "Ilaria",
        "Virginia",
        "Suzana",
        "Rose-Marie",
        "Jeanine",
        "Margarita",
        "Joanna",
        "Coralie",
        "Elif",
        "Dina",
        "Janina",
        "Josefine",
        "Mina",
        "Hannelore",
        "Gordana",
        "Luciana",
        "Heike",
        "Aurelia",
        "Luna",
        "Dagmar",
        "Filomena",
        "Dolores",
        "Raymonde",
        "Prisca",
        "Annick",
        "Huguette",
        "Elisabetha",
        "Dragana",
        "Leona",
        "Elke",
        "Inès",
        "Valerie",
        "Ayse",
        "Amelia",
        "Flurina",
        "Marie-Thérèse",
        "Roswitha",
        "Rosanna",
        "Ginette",
        "Matilde",
        "Mélissa",
        "Yolande",
        "Océane",
        "Giada",
        "Murielle",
        "Danijela",
        "Sanja",
        "Slavica",
        "Adelina",
        "Valentine",
        "Catarina",
        "Raquel",
        "Emmanuelle",
        "Dana",
        "Erica",
        "Marcelle",
        "Nancy",
        "Germaine",
        "Concetta",
        "Gianna",
        "Jade",
        "Lucienne",
        "Letizia",
        "Fatime",
        "Odette",
        "Solange",
        "Lily",
        "Nada",
        "Lucy",
        "Margherita",
        "Hana",
        "Elisabetta",
        "Leana",
        "Vivienne",
        "Viola",
        "Ljiljana",
        "Yasmin",
        "Agatha",
        "Jutta",
        "Anabela",
        "Laila",
        "Romana",
        "Gaëlle",
        "Belinda",
        "Aida",
        "Federica",
        "Giuliana",
        "Marie-Claire",
        "Mirella",
        "Eliana",
        "Paulina",
        "Diane",
        "Paulette",
        "Mona",
        "Milica",
        "Corinna",
        "Yasmine",
        "Annalise",
        "Hatice",
        "Alyssa",
        "Ellen",
        "Kelly",
        "Biljana",
        "Noelia",
        "Alisha",
        "Léonie",
        "Amandine",
        "Amelie",
        "Amy",
        "Lilli",
        "Nelli",
        "Margaux",
        "Melisa",
        "Anneliese",
        "Marie-Claude",
        "Sheila",
        "Dragica",
        "Xenia",
        "Violeta",
        "Annie",
        "Lou",
        "Meret",
        "Ute",
        "Irena",
        "Catia",
        "Giuseppa",
        "Sybille",
        "Lana",
        "Celina",
        "Aylin",
        "Zita",
        "Karolina",
        "Louisa",
        "Luise",
        "Rosina",
        "Jeanette",
        "Sharon",
        "Henriette",
        "Joy",
        "Inge",
        "Carola",
        "Tiffany",
        "Margarete",
        "Marietta",
        "Josefa",
        "Leyla",
        "Nuria",
        "Anne-Lise",
        "Gilberte",
        "Giorgia",
        "Emanuela",
        "Daisy",
        "Angelica",
        "Josephine",
        "Ilse",
        "Natasa",
        "Andrina",
        "Fabiana",
        "Flora",
        "Maude",
        "Melinda",
        "Silke",
        "Enya",
        "Amira",
        "Beate",
        "Viktoria",
        "Francisca",
        "Merita",
        "Odile",
        "Snezana",
        "Ariana",
        "Carol",
        "Medina",
        "Romy",
        "Noëlle",
        "Alissa",
        "Elisabete",
        "Camilla",
        "Miranda",
        "Leonora",
        "Lejla",
        "Zeynep",
        "Maeva",
        "Domenica",
        "Raffaella",
        "Salomé",
        "Ornella",
        "Rosaria",
        "Alisa",
        "Alba",
        "Zorica",
        "Roxane",
        "Raphaela",
        "Inês",
        "Hermine",
        "Waltraud",
        "Aude",
        "Selin",
        "Claude",
        "Arianna",
        "Angélique",
        "Leticia",
        "Malin",
        "Viviana",
        "Annelies",
        "Damaris",
        "Liv",
        "Maëlle",
        "Sigrid",
        "Jill",
        "Karina",
        "Liana",
        "Eline",
        "Lotte",
        "Lise",
        "Rina",
        "Morena",
        "Marilena",
        "Leonor",
        "Annamaria",
        "Albina",
        "Dijana",
        "Grazia",
        "Ester",
        "Vivien",
        "Käthi",
        "Tara",
        "Aurore",
        "Katarzyna",
        "Amalia",
        "Celia",
        "Seline",
        "Anisa",
        "Azra",
        "Adeline",
        "Fabiola",
        "Agnieszka",
        "Greta",
        "Jane",
        "Vincenza",
        "Rosalia",
        "Marie-Christine",
        "Marijana",
        "Jara",
        "Gudrun",
        "Edona",
        "Gioia",
        "Marcia",
        "Myrtha",
        "Ekaterina",
        "Lucette",
        "Gertrude",
        "Ljubica",
        "Adrienne",
        "Malika",
        "Ava",
        "Yael",
        "Lola",
        "Marinette",
        "Teuta",
        "Joelle",
        "Beata",
        "Line",
        "Priscilla",
        "Rosalie",
        "Mariette",
        "Ada",
        "Marielle",
        "Juliane",
        "Emina",
        "Arta",
        "Margarida",
        "Claire-Lise",
        "Gaia",
        "Antje",
        "Raffaela",
        "Mercedes",
        "Vlora",
        "Arlinda",
        "Nicoletta",
        "Alison",
        "Ottilia",
        "Clémence",
        "Lisbeth",
        "Shqipe",
        "Adele",
        "Maryline",
        "Sónia",
        "Ewa",
        "Drita",
        "Gladys",
        "Dilara",
        "Malgorzata",
        "Eleni",
        "Sandy",
        "Marika",
        "Marthe",
        "Norma",
        "Carolin",
        "Ina",
        "Agathe",
        "Alea",
        "Anke",
        "Zora",
        "Cristiana",
        "Marie-José",
        "Liridona",
        "Romane",
        "Noa",
        "Shpresa",
        "Esma",
        "Assunta",
        "Vittoria",
        "Blerta",
        "Ema",
        "Elma",
        "Anika",
        "Marie-France",
        "Samanta",
        "Mariella",
        "Meryem",
        "Tânia",
        "Ghislaine",
        "Marica",
        "Desirée",
        "Britta",
        "Joséphine",
        "Moira",
        "Maud",
        "Gemma",
        "Silja",
        "Sladjana",
        "Sanela",
        "Iva",
        "Ann",
        "Nadège",
        "Corine",
        "Frida",
        "Cheyenne",
        "Theres",
        "Lilia",
        "Matilda",
        "Geraldine",
        "Lisette",
        "Margaret",
        "Eloïse",
        "Felicia",
        "Hulda",
        "Kathleen",
        "Erina",
        "Jovana",
        "Timea",
        "Sofie",
        "Wanda",
        "Anne-Sophie",
        "Zahra",
        "Florentina",
        "Alexa",
        "Ruzica",
        "Ganimete",
        "Herta",
        "Agata",
        "Yasemin",
        "Frédérique",
        "Nicola",
        "Norah",
        "Lorenza",
        "Ilenia",
        "Khadija",
        "Elda",
        "Felicitas",
        "Charline",
        "Ela",
        "Eliza",
        "Katalin",
        "Rafaela",
        "Tanya",
        "Theresa",
        "Floriane",
        "Katherine",
        "Asia",
        "Mathilda",
        "Fabia",
        "Fatmire",
        "Imelda",
        "Susi",
        "Zuzana",
        "Cassandra",
        "Donatella",
        "Antonina",
        "Luz",
        "Yasmina",
        "Eleonore",
        "Bluette",
        "Malea",
        "Danica",
        "Dunja",
        "Kirsten",
        "Eileen",
        "Mirela",
        "Vanesa",
        "Filipa",
        "Léna",
        "Jaqueline",
        "Evelin",
        "Violette",
        "Vjollca",
        "Mariam",
        "Maryam",
        "Amela",
        "Luigia",
        "Noëmi",
        "Joyce",
        "Pierina",
        "Aferdita",
        "Cátia",
        "Mandy",
        "Regine",
        "Branka",
        "Radmila",
        "Vreneli",
        "Marcella",
        "Grace",
        "Ludivine",
        "Natasha",
        "Olena",
        "Elea",
        "Jil",
        "Anne-Laure",
        "Eléonore",
        "Ayla",
        "Mégane",
        "Maddalena",
        "Sereina",
        "Tenzin",
        "Dafina",
        "Eve",
        "Leslie",
        "Alix",
        "Kiara",
        "Ardita",
        "Aisha",
        "Margit",
        "Janet",
        "Kira",
        "Margreth",
        "Amra",
        "Marcela",
        "Solène",
        "Kristin",
        "Fitore",
        "Rosalba",
        "Edina",
        "Mariangela",
        "Agnese",
        "Albulena",
        "Joanne",
        "Ylenia",
        "Clarissa",
        "Magda",
        "Marie-Laure",
        "Anna-Maria",
        "Luljeta",
        "Marjorie",
        "Annalisa",
        "Lidija",
        "Ajla",
        "Sanije",
        "Wendy",
        "Wilma",
        "Layla",
        "Thea",
        "Esra",
        "Jaël",
        "Fernande",
        "Vania",
        "Lindita",
        "Tessa",
        "Mimoza",
        "Kata",
        "Maryse",
        "Dalia",
        "Käthe",
        "Blanka",
        "Katerina",
        "Ophélie",
        "Leni",
        "Egzona",
        "Eugenia",
        "Lavinia",
        "Léane",
        "Bukurije",
        "Cordula",
        "Teodora",
        "Nikolina",
        "Özlem",
        "Lauriane",
        "Milka",
        "Patrícia",
        "Aloisia",
        "Lya",
        "Derya",
        "Margret",
        "Juana",
        "Vilma",
        "Annabelle",
        "Besarta",
        "Norina",
        "Cláudia",
        "Nives",
        "Hanife",
        "Blerina",
        "Lydie",
        "Gerlinde",
        "Déborah",
        "Mirlinda",
        "Vivian",
        "María",
        "Shania",
        "Romaine",
        "Tuana",
        "Berthe",
        "Friederike",
        "Susann",
        "Rosetta",
        "Hava",
        "Kaltrina",
        "Marie-Jeanne",
        "Iryna",
        "Mihaela",
    )

    first_names = first_names_male + first_names_female

    last_names = (
        "Ackermann",
        "Aebi",
        "Albrecht",
        "Ammann",
        "Amrein",
        "Arnold",
        "Bachmann",
        "Bader",
        "Bär",
        "Bättig",
        "Bauer",
        "Baumann",
        "Baumgartner",
        "Baur",
        "Beck",
        "Benz",
        "Berger",
        "Bernasconi",
        "Betschart",
        "Bianchi",
        "Bieri",
        "Blaser",
        "Blum",
        "Bolliger",
        "Bosshard",
        "Braun",
        "Brun",
        "Brunner",
        "Bucher",
        "Bühler",
        "Bühlmann",
        "Burri",
        "Christen",
        "Egger",
        "Egli",
        "Eichenberger",
        "Erni",
        "Ernst",
        "Eugster",
        "Fankhauser",
        "Favre",
        "Fehr",
        "Felber",
        "Felder",
        "Ferrari",
        "Fischer",
        "Flückiger",
        "Forster",
        "Frei",
        "Frey",
        "Frick",
        "Friedli",
        "Fuchs",
        "Furrer",
        "Gasser",
        "Geiger",
        "Gerber",
        "Gfeller",
        "Giger",
        "Gloor",
        "Graf",
        "Grob",
        "Gross",
        "Gut",
        "Haas",
        "Häfliger",
        "Hafner",
        "Hartmann",
        "Hasler",
        "Hauser",
        "Hermann",
        "Herzog",
        "Hess",
        "Hirt",
        "Hodel",
        "Hofer",
        "Hoffmann",
        "Hofmann",
        "Hofstetter",
        "Hotz",
        "Huber",
        "Hug",
        "Hunziker",
        "Hürlimann",
        "Imhof",
        "Isler",
        "Iten",
        "Jäggi",
        "Jenni",
        "Jost",
        "Kägi",
        "Kaiser",
        "Kälin",
        "Käser",
        "Kaufmann",
        "Keller",
        "Kern",
        "Kessler",
        "Knecht",
        "Koch",
        "Kohler",
        "Kuhn",
        "Küng",
        "Kunz",
        "Lang",
        "Lanz",
        "Lehmann",
        "Leu",
        "Leunberger",
        "Lüscher",
        "Lustenberger",
        "Lüthi",
        "Lutz",
        "Mäder",
        "Maier",
        "Marti",
        "Martin",
        "Maurer",
        "Mayer",
        "Meier",
        "Meili",
        "Meister",
        "Merz",
        "Mettler",
        "Meyer",
        "Michel",
        "Moser",
        "Müller",
        "Näf",
        "Ott",
        "Peter",
        "Pfister",
        "Portmann",
        "Probst",
        "Rey",
        "Ritter",
        "Roos",
        "Roth",
        "Rüegg",
        "Schäfer",
        "Schaller",
        "Schär",
        "Schärer",
        "Schaub",
        "Scheidegger",
        "Schenk",
        "Scherrer",
        "Schlatter",
        "Schmid",
        "Schmidt",
        "Schneider",
        "Schnyder",
        "Schoch",
        "Schuler",
        "Schumacher",
        "Schürch",
        "Schwab",
        "Schwarz",
        "Schweizer",
        "Seiler",
        "Senn",
        "Sidler",
        "Siegrist",
        "Sigrist",
        "Spörri",
        "Stadelmann",
        "Stalder",
        "Staub",
        "Stauffer",
        "Steffen",
        "Steiger",
        "Steiner",
        "Steinmann",
        "Stettler",
        "Stocker",
        "Stöckli",
        "Stucki",
        "Studer",
        "Stutz",
        "Suter",
        "Sutter",
        "Tanner",
        "Thommen",
        "Tobler",
        "Vogel",
        "Vogt",
        "Wagner",
        "Walder",
        "Walter",
        "Weber",
        "Wegmann",
        "Wehrli",
        "Weibel",
        "Wenger",
        "Wettstein",
        "Widmer",
        "Winkler",
        "Wirth",
        "Wirz",
        "Wolf",
        "Wüthrich",
        "Wyss",
        "Zbinden",
        "Zehnder",
        "Ziegler",
        "Zimmermann",
        "Zingg",
        "Zollinger",
        "Zürcher",
    )

    prefixes = ("Dr.", "Prof.")



from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    price_formats = ["#,#0", "%#,#0", "%##,#0", "%.###,#0", "%#.###,#0"]

    def pricetag(self) -> str:
        return self.numerify(self.random_element(self.price_formats)) + "\N{NO-BREAK SPACE}Kč"



from randum.providers.person.bn_BD import translate_to_bengali_digits

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``bn_BD`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Bangladesh
    """

    # noinspection DuplicatedCode
    cities = (
        "বরগুনা",
        "বরিশাল",
        "বরিশাল মেট্রো",
        "ভোলা",
        "বান্দরবান",
        "ব্রাহ্মণবাড়িয়া",
        "বাগেরহাট",
        "বগুড়া",
        "চাঁদপুর",
        "চট্টগ্রাম",
        "চট্ট মেট্রো",
        "কুমিল্লা",
        "কক্সবাজার",
        "চুয়াডাঙ্গা",
        "ঢাকা",
        "ঢাকা মেট্রো",
        "দিনাজপুর",
        "ফরিদপুর",
        "ফেনী",
        "গাজীপুর",
        "গোপালগঞ্জ",
        "গাইবান্ধা",
        "হবিগঞ্জ",
        "ঝালকাঠি",
        "যশোর",
        "ঝিনাইদহ",
        "জামালপুর",
        "জয়পুরহাট",
        "খাগড়াছড়ি",
        "কিশোরগঞ্জ",
        "খুলনা",
        "খুলনা মেট্রো",
        "কুষ্টিয়া",
        "কুড়িগ্রাম",
        "লক্ষ্মীপুর",
        "লালমনিরহাট",
        "মাদারীপুর",
        "মানিকগঞ্জ",
        "মুন্সীগঞ্জ",
        "মাগুরা",
        "মেহেরপুর",
        "ময়মনসিংহ",
        "মৌলভীবাজার",
        "নোয়াখালী",
        "নারায়ণগঞ্জ",
        "নরসিংদী",
        "নড়াইল",
        "নেত্রকোণা",
        "নওগাঁ",
        "নাটোর",
        "চাঁপাইনবাবগঞ্জ",
        "নীলফামারী",
        "পটুয়াখালী",
        "পিরোজপুর",
        "পাবনা",
        "পঞ্চগড়",
        "রাঙ্গামাটি",
        "রাজবাড়ী",
        "রাজশাহী",
        "রাজ মেট্রো",
        "রংপুর",
        "শরীয়তপুর",
        "সাতক্ষীরা",
        "শেরপুর",
        "সিরাজগঞ্জ",
        "সুনামগঞ্জ",
        "সিলেট",
        "সিলেট মেট্রো",
        "টাঙ্গাইল",
        "ঠাকুরগাঁও",
    )

    vehicle_category_letters = (
        "অ",
        "ই",
        "উ",
        "এ",
        "ক",
        "খ",
        "গ",
        "ঘ",
        "ঙ",
        "চ",
        "ছ",
        "জ",
        "ঝ",
        "ত",
        "থ",
        "ঢ",
        "ড",
        "ট",
        "ঠ",
        "দ",
        "ধ",
        "ন",
        "প",
        "ফ",
        "ব",
        "ভ",
        "ম",
        "য",
        "র",
        "ল",
        "শ",
        "স",
        "হ",
    )

    vehicle_category_numbers = (
        "১১",
        "১২",
        "১৩",
        "১৪",
        "১৫",
        "১৬",
        "১৭",
        "১৮",
        "১৯",
        "২০",
        "২১",
        "২২",
        "২৩",
        "২৪",
        "২৫",
        "২৬",
        "২৭",
        "২৮",
        "২৯",
        "৩০",
        "৩১",
        "৩২",
        "৩৩",
        "৩৪",
        "৩৫",
        "৩৬",
        "৩৭",
        "৩৮",
        "৩৯",
        "৪০",
        "৪১",
        "৪২",
        "৪৩",
        "৪৪",
        "৪৫",
        "৪৬",
        "৪৭",
        "৪৮",
        "৪৯",
        "৫০",
        "৫১",
        "৫২",
        "৫৩",
        "৫৪",
        "৫৫",
        "৫৬",
        "৫৭",
        "৫৮",
        "৫৯",
        "৬০",
        "৬১",
        "৬২",
        "৬৩",
        "৬৪",
        "৬৫",
        "৬৬",
        "৬৭",
        "৬৮",
        "৬৯",
        "৭০",
        "৭১",
        "৭২",
        "৭৩",
        "৭৪",
        "৭৫",
        "৭৬",
        "৭৭",
        "৭৮",
        "৭৯",
        "৮০",
        "৮১",
        "৮২",
        "৮৩",
        "৮৪",
        "৮৫",
        "৮৬",
        "৮৭",
        "৮৮",
        "৮৯",
        "৯০",
        "৯১",
        "৯২",
        "৯৩",
        "৯৪",
        "৯৫",
        "৯৬",
        "৯৭",
        "৯৮",
        "৯৯",
    )

    vehicle_serial_number_formats = ("%###",)

    license_plate_formats = (
        "{{city_name}}-{{vehicle_category_letter}} {{vehicle_category_number}}-{{vehicle_serial_number}}",
    )

    def city_name(self) -> str:
        """
        :example: 'ঢাকা মেট্রো'
        """
        return self.random_element(self.cities)

    def vehicle_category_letter(self) -> str:
        """
        :example: 'ব'
        """
        return self.random_element(self.vehicle_category_letters)

    def vehicle_category_number(self) -> str:
        """
        :example: '১১'
        """
        return self.random_element(self.vehicle_category_numbers)

    def vehicle_serial_number(self) -> str:
        """
        Generate a 4 digits vehicle serial number.
        :example: '৫৪৩২'
        """
        return translate_to_bengali_digits(self.numerify(self.random_element(self.vehicle_serial_number_formats)))

    def license_plate(self) -> str:
        """
        Generate a license plate.
        :example: 'বরিশাল-ভ ৬৭-৪৫৯৩'
        """
        pattern: str = self.random_element(self.license_plate_formats)
        return self.generator.parse(pattern)
